@@ -20,7 +20,7 @@
 AboutDialog::AboutDialog(const QString tversion, QWidget *parent)
     : QDialog(parent)
 {
-   //qDebug() << "AboutDialog::AboutDialog" << endl;
+    //qDebug() << "AboutDialog::AboutDialog" << endl;
 
     QPixmap pixmap(":/img/klog_256x256.png");
 
@@ -70,22 +70,24 @@ AboutDialog::AboutDialog(const QString tversion, QWidget *parent)
     QString author2 = QString("<tr><td>Akihiro Koda</td>")  + QString("<td><a href=\"https://www.qrz.com/db/jl3oxr\">JL3OXR</a></td>") + "<td>(2016-2017)</td></tr>";
     QString author3 = QString("<tr><td>Andrew Goldie</td>") + QString("<td><a href=\"https://www.qrz.com/db/zl2agc\">ZL2ACG</a></td>") + "<td>(2009-2010)</td></tr>";
 
-    QString authorText = tr("KLog is developed by a very small team and you are invited to join!") + "<br><br>" + tr("If you want to provide support you are welcome to join the") + " <a href=\"https://lists.nongnu.org/mailman/listinfo/klog-devel\">" + tr("KLog development mailing list") + "</a>"+ tr("!") + "<br><br>" + tr("You can also help us by sending bug reports or small code contributions, ideas or whatever you think may improve KLog.");
+    QString authorText = tr("KLog is developed by a very small team and you are invited to join!") + "<br><br>" + tr("If you want to provide support you are welcome to join the <a href=\"https://lists.nongnu.org/mailman/listinfo/klog-devel\">KLog development mailing list</a>!") + "<br><br>" + tr("You can also help us by sending bug reports or small code contributions, ideas or whatever you think may improve KLog.");
     QString authors = "<center><h2>" + tr("Authors") + "</h2></center><br>" + authorText + "<br><table>" + author1 + author2 + author3 + "</table>";
 
 
     QString translator1 = QString("<tr><td>Catalan</td>")  + QString("<td>Josep Ma. Ferrer</td>") + QString("<td><a href=\"mailto://kde-i18n-ca@kde.org\">KDE Catalan translation team</a></td></tr>");
     QString translator2 = QString("<tr><td>Croatian</td>")  + QString("<td>Kristijan Conkas</td>") + QString("<td><a href=\"https://www.qrz.com/db/m0nkc\">M0NKC</a></td></tr>");
-    QString translator3 = QString("<tr><td>Finnish</td>")  + QString("<td>Kristjan Lorents</td>") + QString("<td><a href=\"debian-i18n@lists.debian.org\">Debian translation team</a></td></tr>");
-    QString translator4 = QString("<tr><td>Danish</td>")  + QString("<td>Joe Hansen</td>") + QString("<td><a href=\"mailto://debian-l10n-danish@list.debian.org\">Danish Debian translation team</a></td></tr>");
-    QString translator5 = QString("<tr><td>Italian</td>")  + QString("<td>Simona Pisano</td>") + QString("<td><a href=\"https://www.qrz.com/db/iu5hiu\">IU5HIU</a></td></tr>");
-    QString translator6 = QString("<tr><td>Japanese</td>")  + QString("<td>Akihiro Koda</td>") + QString("<td><a href=\"https://www.qrz.com/db/jl3oxr\">JL3OXR</a></td></tr>");
-    QString translator7 = QString("<tr><td>Polish</td>")  + QString("<td>Piotr Ludwig</td>") + QString("<td><a href=\"https://www.qrz.com/db/la7rra\">LA7RRA</a></td></tr>");
-    QString translator8 = QString("<tr><td>Spanish</td>") + QString("<td>Jaime Robles</td>") + QString("<td><a href=\"https://www.qrz.com/db/ea4tv\">EA4TV</a></td></tr>");
+    QString translator3 = QString("<tr><td>Finnish</td>")  + QString("<td>Kristjan Lorents</td>") + QString("<td><a href=\"debian-i18n@lists.debian.org\">Finnish Debian translation team</a></td></tr>");
+    QString translator4 = QString("<tr><td>French</td>") + QString("<td>Christophe Lefebvre</td>") + QString("<td><a href=\"https://www.qrz.com/db/f4hwl\">F4HWL</a></td></tr>");
+    QString translator5 = QString("<tr><td>Danish</td>")  + QString("<td>Joe Hansen</td>") + QString("<td><a href=\"mailto://debian-l10n-danish@list.debian.org\">Danish Debian translation team</a></td></tr>");
+    QString translator6 = QString("<tr><td>German</td>") + QString("<td>Burhard Lück</td>") + QString("<td><a href=\"mailto://kde-i18n-de@kde.org\">KDE German translation team</a></td></tr>");
+    QString translator7 = QString("<tr><td>Italian</td>")  + QString("<td>Simona Pisano</td>") + QString("<td><a href=\"https://www.qrz.com/db/iu5hiu\">IU5HIU</a></td></tr>");
+    QString translator8 = QString("<tr><td>Japanese</td>")  + QString("<td>Akihiro Koda</td>") + QString("<td><a href=\"https://www.qrz.com/db/jl3oxr\">JL3OXR</a></td></tr>");
+    QString translator9 = QString("<tr><td>Polish</td>")  + QString("<td>Piotr Ludwig</td>") + QString("<td><a href=\"https://www.qrz.com/db/la7rra\">LA7RRA</a></td></tr>");
+    QString translator10 = QString("<tr><td>Spanish</td>") + QString("<td>Jaime Robles</td>") + QString("<td><a href=\"https://www.qrz.com/db/ea4tv\">EA4TV</a></td></tr>");
 
 
-    QString translatorsText = tr("Translators bring KLog into your language. They are really an important part of the KLog development team.") + "<br><br>" + tr("If KLog is still not in your language and you want to help us, you are welcome to contact us through the") + " <a href=\"https://lists.nongnu.org/mailman/listinfo/klog-devel\">" + tr("KLog development mailing list") + "</a>" + tr("!");
-    QString translators = "<center><h2>" + tr("Translators") + "</h2></center><br>" + translatorsText + "<br><table>" + translator1 + translator2 + translator3 + translator4 + translator5 + translator6 + translator7 + translator8 + "</table>";
+    QString translatorsText = tr("Translators bring KLog into your language. They are really an important part of the KLog development team.") + "<br><br>" + tr("If KLog is still not in your language and you want to help us, you are welcome to contact us through the <a href=\"https://lists.nongnu.org/mailman/listinfo/klog-devel\">KLog development mailing list</a>!");
+    QString translators = "<center><h2>" + tr("Translators") + "</h2></center><br>" + translatorsText + "<br><table>" + translator1 + translator2 + translator3 + translator4 + translator5 + translator6 + translator7 + translator8 + translator9 + translator10 + "</table>";
 
     QLabel *authorsLabel = new QLabel(authors);
     authorsLabel->setWordWrap(true);
@@ -104,6 +106,7 @@ AboutDialog::AboutDialog(const QString tversion, QWidget *parent)
             tr("Be aware that you can enable/disable this feature from the Misc tab in the Setup page") + ".</b>";
 
     QLabel *privacyLabel = new QLabel(privacy);
+    privacyLabel->setAlignment(Qt::AlignJustify);
     privacyLabel->setWordWrap(true);
     privacyLabel->setOpenExternalLinks(true);
     privacyLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
@@ -117,15 +120,12 @@ AboutDialog::AboutDialog(const QString tversion, QWidget *parent)
     QGridLayout *layout1 = new QGridLayout;
     layout1->addWidget(logoLabel , 0, 0, 1, 1);
     layout1->addWidget(copyRightLabel, 0, 1, 4, 4);
-    layout1->addWidget(buttonBox, 4, 0, 1, 5);
-
     tab1->setLayout(layout1);
 
 
     QGridLayout *layout2 = new QGridLayout;
     layout2->addWidget(logoLabel2 , 0, 0, 1, 1);
     layout2->addWidget(authorsLabel, 0, 1, 4, 4);
-    //layout2->addWidget(buttonBox, 4, 0, 1, 5);
     tab2->setLayout(layout2);
 
 
@@ -147,11 +147,12 @@ AboutDialog::AboutDialog(const QString tversion, QWidget *parent)
     tabw->addTab(tab4, tr("Privacy"));
 
     layout->addWidget(tabw);
+    layout->addWidget(buttonBox, 1, 0, Qt::AlignRight);
 
     setLayout(layout);
 
 
-    //qDebug() << "AboutDialog::AboutDialog - END" << endl;
+     //qDebug() << "AboutDialog::AboutDialog - END" << endl;
 
 }
 AboutDialog::~AboutDialog()
