@@ -40,7 +40,7 @@
 class QSqlRelationalTableModel;
 
 // Previous db update 0.011
-const float DBVersionf = 0.012; // TODO:
+const float DBVersionf = 0.014; // TODO:
 
 struct AwarddxccEntry
 { // Information to update the awarddxcc table; For other Award tables, the DXCC is just the ID of the award element
@@ -135,6 +135,7 @@ private:
 
     bool createDataBase();
     bool isTheDBCreated();
+    bool isTheTableExisting(const QString _tableName);
     bool hasTheTableData(const QString _tableName);
     bool updateToLatest();
     bool updateTo003(); // Updates the DB to 0.0.3
@@ -147,8 +148,10 @@ private:
     bool updateTo010(); // Updates DB and recreates the supportedcontest table
     bool updateTo011(); // Updates DB and recreates Satellite data
     bool updateTo012(); // Updates the flags and so on.
+    bool updateTo013(); // Update the qsl_via_enumeration bug caused for calling the table just qsl_via
+    bool updateTo014(); // Update the Satellite DB
     bool updateTableLog(const int _v);
-    bool updateDBVersion();
+    bool updateDBVersion(QString _softV, QString _dbV);
 
     bool createTheBandQuickReference();
     bool createTheModeQuickReference();
@@ -193,6 +196,9 @@ private:
 
     bool populateTableSupportedContest();
 
+    bool createTableQSL_Via_enumeration();
+    bool populateTableQSL_Via_enumeration();
+
     bool howManyQSOsInLog(const int i);
     //void showError();
 
