@@ -30,7 +30,7 @@
 
 DataProxy::DataProxy()
 {
-   //qDebug() << "DataProxy::DataProxy"  << endl;
+    //qDebug() << "DataProxy::DataProxy"  << endl;
 }
 
 DataProxy::~DataProxy()
@@ -327,6 +327,16 @@ bool DataProxy::updateAwardWAZ()
 {
     return false;
 }
+
+bool DataProxy::addQSOFromWSJTX(const QString _dxcall, const double _freq, const QString _mode,
+                                const QString _dx_grid, const QString _time_off, const QString _report_sent, const QString _report_rec,
+                                const QString _tx_power, const QString _comments, const QString _name, const QString _time_on,
+                                const int _dxcc, const QString _opQrz, const QString _stQrz, const QString _myLoc, const int _logN)
+{
+    return false;
+}
+
+
 bool DataProxy::deleteQSO(const int _qsoId)
 {
     return false;
@@ -414,6 +424,22 @@ int DataProxy::getCQzonYear(const int _year, const int _logNumber)
     return -1;
 }
 
+int DataProxy::getQSOsWithDXCC(const int _dxcc, const int _logNumber)
+{
+    return -1;
+}
+
+int DataProxy::getQSOsAtHour(const int _hour, const int _log)
+{
+    return -1;
+}
+
+int DataProxy::getQSOsOnMonth(const int _month, const int _log)
+{
+    return -1;
+}
+
+
 bool DataProxy::newDXMarathon(const int _dxcc, const int _cq, const int _year, const int _logNumber)
 {
     return false;
@@ -442,6 +468,16 @@ QStringList DataProxy::getPropModeList()
     return QStringList();
 }
 
+bool DataProxy::clearSatList()
+{
+    return false;
+}
+
+bool DataProxy::addSatellite(const QString _arrlId, const QString _name, const QString _downLink, const QString _upLink, const QString _mode)
+{
+    return false;
+}
+
 QStringList DataProxy::getSatellitesList()
 {
     return QStringList();
@@ -457,6 +493,11 @@ QString DataProxy::getSatelliteDownlink(const QString _sat)
     return QString();
 }
 
+QString DataProxy::getSatelliteMode(const QString _sat)
+{
+    return QString();
+}
+
 QStringList DataProxy::getQSLRcvdList()
 {
     return QStringList();
@@ -569,6 +610,25 @@ int DataProxy::getHowManyConfirmedQSLInLog(const int _log)
 {
     return 0;
 }
+int DataProxy::getHowManyQSLSentInLog(const int _log)
+{
+    return 0;
+}
+
+int DataProxy::getQSOsWithContinent(const QString _cont, const int _logNumber)
+{
+    return 0;
+}
+
+int DataProxy::getQSOsInBand(const QString _band, const int _log)
+{
+    return 0;
+}
+
+int DataProxy::getQSOsInMode(const QString _mode, const int _log)
+{
+    return 0;
+}
 
 bool DataProxy::addNewLog (const QStringList _qs)
 {
@@ -670,6 +730,11 @@ QStringList DataProxy::getEntitiesNames()
     return QStringList();
 }
 
+QStringList DataProxy::getEntitiesIds()
+{
+    return QStringList();
+}
+
 int DataProxy::getHowManyEntities()
 {
     return -1;
