@@ -83,10 +83,17 @@ public:
     virtual QStringList getModesInLog(const int _log);
     virtual int getMostUsedBand(const int _log);
     virtual int getMostUsedMode(const int _log);
+    virtual int getQSOsInBand(const QString _band, const int _log);
+    virtual int getQSOsInMode(const QString _mode, const int _log);    
 
     virtual int getLastQSOid();
     virtual bool clearLog();
 
+    virtual bool addQSOFromWSJTX(const QString _dxcall, const double _freq, const QString _mode,
+                                 const QString _dx_grid, const QString _time_off, const QString _report_sent, const QString _report_rec,
+                                 const QString _tx_power, const QString _comments, const QString _name, const QString _time_on,
+                                 const int _dxcc, const QString _opQrz, const QString _stQrz, const QString _myLoc, const int _logN);
+
     virtual bool deleteQSO(const int _qsoId);
     virtual int isWorkedB4(const QString _qrz, const int _currentLog);
     virtual bool isThisQSODuplicated(const QString _qrz, const QString _date, const QString _time, const int _band, const int _mode);
@@ -143,6 +150,7 @@ public:
     virtual int getDXCCFromPrefix(const QString _p);
     virtual QString getEntityPrefixes(const int _enti);
     virtual QStringList getEntitiesNames();
+    virtual QStringList getEntitiesIds();
     virtual int getHowManyEntities();
     virtual int getMaxEntityID(bool limit);                 // limit = true implies that it will only shouw ARRL valid DXCC (i.e. will not count Sicily)
 
@@ -155,6 +163,10 @@ public:
     virtual int getQSOonYear(const int _year, const int _logNumber);
     virtual int getDXCConYear(const int _year, const int _logNumber);
     virtual int getCQzonYear(const int _year, const int _logNumber);
+    virtual int getQSOsWithDXCC(const int _dxcc, const int _logNumber);
+    virtual int getQSOsAtHour(const int _hour, const int _log);
+    virtual int getQSOsOnMonth(const int _month, const int _log);
+
     virtual bool newDXMarathon(const int _dxcc, const int _cq, const int _year, const int _logNumber);
 
     virtual QStringList getContestNames();
@@ -169,9 +181,13 @@ public:
 
     virtual QStringList getBandNames();
     virtual QStringList getPropModeList();
+
+    virtual bool clearSatList();
+    virtual bool addSatellite(const QString _arrlId, const QString _name, const QString _downLink, const QString _upLink, const QString _mode);
     virtual QStringList getSatellitesList();
     virtual QString getSatelliteUplink(const QString _sat);
     virtual QString getSatelliteDownlink(const QString _sat);
+    virtual QString getSatelliteMode(const QString _sat);
     virtual QStringList getQSLRcvdList();
     virtual QStringList getQSLSentList();
     virtual QStringList getClubLogStatusList();
@@ -182,6 +198,8 @@ public:
     virtual bool fillEmptyDXCCInTheLog();
     virtual int getHowManyQSOInLog(const int _log);
     virtual int getHowManyConfirmedQSLInLog(const int _log);
+    virtual int getHowManyQSLSentInLog(const int _log);
+    virtual int getQSOsWithContinent(const QString _cont, const int _logNumber);
     virtual int getNumberOfManagedLogs();
     virtual int getMaxLogNumber();
     virtual QStringList getListOfManagedLogs();
