@@ -83,6 +83,10 @@ public:
     bool isThisFreqInBand(const QString b, const QString fr);
 
     int getLastQSOid();
+    bool addQSOFromWSJTX(const QString _dxcall, const double _freq, const QString _mode,
+                                 const QString _dx_grid, const QString _time_off, const QString _report_sent, const QString _report_rec,
+                                 const QString _tx_power, const QString _comments, const QString _name, const QString _time_on,
+                                 const int _dxcc, const QString _opQrz, const QString _stQrz, const QString _myLoc, const int _logN);
 
     bool deleteQSO(const int _qsoId);
     int isWorkedB4(const QString _qrz, const int _currentLog);
@@ -146,6 +150,7 @@ public:
     int getDXCCFromPrefix(const QString _p);
     QString getEntityPrefixes(const int _enti);
     QStringList getEntitiesNames();
+    QStringList getEntitiesIds();
     int getHowManyEntities();
     int getMaxEntityID(bool limit = true);      // limit = true implies that it will only shouw ARRL valid DXCC (i.e. will not count Sicily)
 
@@ -157,9 +162,27 @@ public:
 
     bool clearLog();
 
+
+    // Stats
     int getQSOonYear(const int _year, const int _logNumber);
     int getDXCConYear(const int _year, const int _logNumber);
     int getCQzonYear(const int _year, const int _logNumber);
+    int getQSOsWithDXCC(const int _dxcc, const int _logNumber);
+    int getQSOsAtHour(const int _hour, const int _log);
+    int getQSOsOnMonth(const int _month, const int _log);
+
+    int getHowManyQSOInLog(const int _log);
+    int getHowManyConfirmedQSLInLog(const int _log);
+    int getHowManyQSLSentInLog(const int _log);
+
+    int getQSOsWithContinent(const QString _cont, const int _logNumber);
+
+    int getQSOsInBand(const QString _band, const int _log);
+    int getQSOsInMode(const QString _mode, const int _log);
+
+    // Stats - end
+
+
     bool newDXMarathon(const int _dxcc, const int _cq, const int _year, const int _logNumber);
 
     QStringList getContestNames();
@@ -174,9 +197,13 @@ public:
 
     QStringList getBandNames();
     QStringList getPropModeList();
+
+    bool clearSatList();
+    bool addSatellite(const QString _arrlId, const QString _name, const QString _downLink, const QString _upLink, const QString _mode);
     QStringList getSatellitesList();   
     QString getSatelliteUplink(const QString _sat);
     QString getSatelliteDownlink(const QString _sat);
+    QString getSatelliteMode(const QString _sat);
     QStringList getQSLRcvdList();
     QStringList getQSLSentList();
     QStringList getClubLogStatusList();
@@ -185,8 +212,7 @@ public:
     QStringList getValidCatOptions(const int _currentCat, const int _lowerCa);
 
     bool fillEmptyDXCCInTheLog();
-    int getHowManyQSOInLog(const int _log);
-    int getHowManyConfirmedQSLInLog(const int _log);
+
     int getNumberOfManagedLogs();
     QStringList getListOfManagedLogs();
     int getMaxLogNumber();
