@@ -7,7 +7,7 @@
 
 DownLoadCTY::DownLoadCTY(const QString _klogDir, const QString _klogVersion) : QObject(0)
 {    
-   //qDebug() << "DownLoadCTY::DownLoadCTY(): " << _klogDir << endl;
+    //qDebug() << "DownLoadCTY::DownLoadCTY(): " << _klogDir << endl;
     util = new Utilities;
     url = new QUrl;
     klogDir = _klogDir;
@@ -27,25 +27,25 @@ DownLoadCTY::DownLoadCTY(const QString _klogDir, const QString _klogVersion) : Q
     request->setRawHeader("User-Agent", str);
     //request->setHeader(QNetworkRequest::UserAgentHeader, str);
 
-    //qDebug() << "DownLoadCTY::DownLoadCTY() - UserAgent: " <<  request->rawHeader("QNetworkRequest::UserAgentHeader") << endl;
+     //qDebug() << "DownLoadCTY::DownLoadCTY() - UserAgent: " <<  request->rawHeader("QNetworkRequest::UserAgentHeader") << endl;
 
     QObject::connect(manager, SIGNAL(finished(QNetworkReply*)),this, SLOT(slotDownloadFinished(QNetworkReply*)));
-    //qDebug() << "DownLoadCTY::DownLoadCTY(): - END"  << endl;
+     //qDebug() << "DownLoadCTY::DownLoadCTY(): - END"  << endl;
 }
 
 DownLoadCTY::~DownLoadCTY()
 {
-  //qDebug() << "DownLoadCTY::~DownLoadCTY"  << endl;
+   //qDebug() << "DownLoadCTY::~DownLoadCTY"  << endl;
 }
 
 
 
  void DownLoadCTY::slotDownloadFinished(QNetworkReply *reply)
 {
-  //qDebug() << "DownLoadCTY::slotDownloadFinished"  << endl;
+   //qDebug() << "DownLoadCTY::slotDownloadFinished"  << endl;
 
    QUrl url = reply->url();
-  //qDebug() << "DownLoadCTY::slotDownloadFinished - URL: " << url.toString()  << endl;
+   //qDebug() << "DownLoadCTY::slotDownloadFinished - URL: " << url.toString()  << endl;
 
    QMessageBox msgBox;
    QString aux;
@@ -92,38 +92,38 @@ DownLoadCTY::~DownLoadCTY()
 
 int DownLoadCTY::download()
 {
-  //qDebug() << "DownLoadCTY::download..." << endl;
+   //qDebug() << "DownLoadCTY::download..." << endl;
 
     manager->get(*request);
     return 1;
 }
 
 void DownLoadCTY::slotDownloadProgress(qint64 received, qint64 total) {
-  //qDebug() << "DownLoadCTY::slotDownloadProgress: " << endl;
+   //qDebug() << "DownLoadCTY::slotDownloadProgress: " << endl;
 
-   //qDebug() << "DownLoadCTY::downloadProgress: " << QString::number(received) << "/" << QString::number(total) << endl;
-    //qDebug() << received << total;
+    //qDebug() << "DownLoadCTY::downloadProgress: " << QString::number(received) << "/" << QString::number(total) << endl;
+     //qDebug() << received << total;
 
     emit actionShowProgres(received, total);
 }
 
 void DownLoadCTY::slotErrorManagement(QNetworkReply::NetworkError networkError)
 {
-   //qDebug() << "DownLoadCTY::slotErrorManagement: " << QString::number(networkError) << endl;
+    //qDebug() << "DownLoadCTY::slotErrorManagement: " << QString::number(networkError) << endl;
 
     result = networkError;
 
     if (result == QNetworkReply::NoError)
     {
-       //qDebug() << "DownLoadCTY::downloadFinished: No error" << endl;
+        //qDebug() << "DownLoadCTY::downloadFinished: No error" << endl;
     }
     else if (result == QNetworkReply::HostNotFoundError)
     {
-        //qDebug() << "DownLoadCTY::downloadFinished: Host not found" << endl;
+         //qDebug() << "DownLoadCTY::downloadFinished: Host not found" << endl;
     }
     else
     {
-       //qDebug() << "DownLoadCTY::downloadFinished: ERROR: " << QString::number(result) << endl;
+        //qDebug() << "DownLoadCTY::downloadFinished: ERROR: " << QString::number(result) << endl;
     }
 
     actionError(result);
@@ -131,7 +131,7 @@ void DownLoadCTY::slotErrorManagement(QNetworkReply::NetworkError networkError)
 
 QString DownLoadCTY::saveFileName(const QUrl &url)
 {
-   //qDebug() << "DownLoadCTY::saveFileName" << endl;
+    //qDebug() << "DownLoadCTY::saveFileName" << endl;
     QString path = url.path();
     QString basename = QFileInfo(path).fileName();
     QMessageBox msgBox;
@@ -166,7 +166,7 @@ QString DownLoadCTY::saveFileName(const QUrl &url)
 
 bool DownLoadCTY::saveToDisk(const QString &filename, QIODevice *data)
 {
-    //qDebug() << "DownLoadCTY::saveToDisk: " << filename << endl;
+     //qDebug() << "DownLoadCTY::saveToDisk: " << filename << endl;
     QFile file(filename);
     QMessageBox msgBox;
     QString aux;
@@ -174,7 +174,8 @@ bool DownLoadCTY::saveToDisk(const QString &filename, QIODevice *data)
     if (!file.open(QIODevice::WriteOnly)) {
 
         msgBox.setIcon(QMessageBox::Warning);
-        aux = tr("Could not open ") + filename + tr(" for writing.");
+        aux = tr("Could not open %1 for writing").arg(filename);
+        //aux = tr("Could not open ") + filename + tr(" for writing.");
         msgBox.setText(aux);
         msgBox.setStandardButtons(QMessageBox::Ok);
         msgBox.setDefaultButton(QMessageBox::Ok);
