@@ -11,7 +11,7 @@ TODO: Call the creation of this depending on the bands that the user is using
 
 DXCCStatusWidget::DXCCStatusWidget(DataProxy *dp, QWidget *parent) : QWidget(parent)
 {
-   //qDebug() << "DXCCStatusWidget::DXCCStatusWidget" << endl;
+    //qDebug() << "DXCCStatusWidget::DXCCStatusWidget" << endl;
     dataProxy = dp;
     awards = new Awards(dataProxy);
     world = new World(dataProxy);
@@ -30,14 +30,14 @@ DXCCStatusWidget::DXCCStatusWidget(DataProxy *dp, QWidget *parent) : QWidget(par
 
     setDefaultBands();
     createUI();
-    //qDebug() << "DXCCStatusWidget::DXCCStatusWidget - END" << endl;
+     //qDebug() << "DXCCStatusWidget::DXCCStatusWidget - END" << endl;
 }
 
 DXCCStatusWidget::~DXCCStatusWidget(){}
 
 void DXCCStatusWidget::createUI()
 {
-   //qDebug() << "DXCCStatusWidget::createUI " << endl;
+    //qDebug() << "DXCCStatusWidget::createUI " << endl;
 
     // We remove the vertical header
     hv = dxccView->verticalHeader();
@@ -75,38 +75,47 @@ void DXCCStatusWidget::createUI()
 
 void DXCCStatusWidget::update()
 {
-    //qDebug() << "DXCCStatusWidget::update " << endl;
+   //qDebug() << "DXCCStatusWidget::update " << endl;
     //int entities = world->getHowManyEntities();
     int entities = dataProxy->getMaxEntityID(false);
 
    //qDebug() << "DXCCStatusWidget::update: " << QString::number(entities) << " entities to update" << endl;
     QStringList list;
+   //qDebug() << "DXCCStatusWidget::update: -1"  << endl;
+    list.clear();
+   //qDebug() << "DXCCStatusWidget::update: -2"  << endl;
 
     QString aux;
-    dxccView->sortByColumn(1, Qt::AscendingOrder);
-    dxccView->clearContents();
-
-    tempLog = -1;
-    for (int i=1; i<=entities; i++)
+   //qDebug() << "DXCCStatusWidget::update: -3"  << endl;
+    if (dxccView->columnCount()>1)
     {
-        aux = world->getEntityName(i);
-        list.clear();
-        if (aux.length()>2)
+        //dxccView->sortByColumn(1, Qt::AscendingOrder);
+        dxccView->clearContents();
+        tempLog = -1;
+       //qDebug() << "DXCCStatusWidget::update pre FOR" << endl;
+        for (int i=1; i<=entities; i++)
         {
-            list << QString::number(i) << aux  << bandNames;
-            addEntity(list);
+           //qDebug() << "DXCCStatusWidget::update in FOR " << QString::number(i) << endl;
+            aux = world->getEntityName(i);
+           //qDebug() << "DXCCStatusWidget::update in FOR aux: " << aux << endl;
+            list.clear();
+            if (aux.length()>2)  // Not all integers refers to an entity.
+            {
+                list << QString::number(i) << aux  << bandNames;
+                addEntity(list);
+            }
         }
     }
-    //qDebug() << "DXCCStatusWidget::update END" << endl;
+   //qDebug() << "DXCCStatusWidget::update END" << endl;
 }
 
 void DXCCStatusWidget::addEntity(QStringList const _ent)
 {
-   //qDebug() << "DXCCStatusWidget::addEntity: " << _ent.at(1) << " / " << QString::number(_ent.length()) << endl;
+    //qDebug() << "DXCCStatusWidget::addEntity: " << _ent.at(1) << " / " << QString::number(_ent.length()) << endl;
     // DXCC id, Entity Name, bandName1, bandName2, ...
     if (_ent.length() != numberOfColumns)
     {
-        //qDebug() << "DXCCStatusWidget::addEntity: ERROR: in number of columns" << QString::number(_ent.length()) << "/" << QString::number(numberOfColumns) << endl;
+         //qDebug() << "DXCCStatusWidget::addEntity: ERROR: in number of columns" << QString::number(_ent.length()) << "/" << QString::number(numberOfColumns) << endl;
         return;
     }
 
@@ -119,7 +128,7 @@ void DXCCStatusWidget::addEntity(QStringList const _ent)
 
     if (entName.length()<2)
     {
-        //qDebug() << "DXCCStatusWidget::addEntity: ERROR: entname too short!" << endl;
+         //qDebug() << "DXCCStatusWidget::addEntity: ERROR: entname too short!" << endl;
         return;
     }
 
@@ -140,10 +149,10 @@ void DXCCStatusWidget::addEntity(QStringList const _ent)
     flagSt = ":/flags/" + aux + ".png";
     QIcon flagIcon(flagSt);
 
-    //qDebug() << "DXCCStatusWidget::addEntity: Flag: " << flagSt << endl;
+     //qDebug() << "DXCCStatusWidget::addEntity: Flag: " << flagSt << endl;
 
     dxccView->insertRow(dxccView->rowCount());
-    //qDebug() << "DXCCStatusWidget::addEntity: rowCount:  " << QString::number(dxccView->rowCount()) << endl;
+     //qDebug() << "DXCCStatusWidget::addEntity: rowCount:  " << QString::number(dxccView->rowCount()) << endl;
 
     QTableWidgetItem *newItemID = new QTableWidgetItem(_ent.at(0));
     newItemID->setTextAlignment(Qt::AlignCenter);
@@ -180,7 +189,7 @@ void DXCCStatusWidget::addEntity(QStringList const _ent)
         }
 
         dxccView->setItem(dxccView->rowCount()-1, i, newItem);
-        //qDebug() << "DXCCStatusWidget::addEntity: rowCount-2:  " << QString::number(dxccView->rowCount()) << "/" << QString::number(i) << " / " << newItem->text() << endl;
+         //qDebug() << "DXCCStatusWidget::addEntity: rowCount-2:  " << QString::number(dxccView->rowCount()) << "/" << QString::number(i) << " / " << newItem->text() << endl;
     }
 
     QTableWidgetItem *newItemName = new QTableWidgetItem(entName);
@@ -206,31 +215,31 @@ void DXCCStatusWidget::addEntity(QStringList const _ent)
     }
 
     dxccView->setItem(dxccView->rowCount()-1, 1, newItemName);
-    //qDebug() << "DXCCStatusWidget::addEntity: END" << endl;
+     //qDebug() << "DXCCStatusWidget::addEntity: END" << endl;
 
 }
 
 void DXCCStatusWidget::setBands(QStringList const _ent, const bool _creating)
 {// Receives the list of band names
 
-  //qDebug() << "DXCCStatusWidget::setBands: " << QString::number(_ent.length()) << endl;
+   //qDebug() << "DXCCStatusWidget::setBands: " << QString::number(_ent.length()) << endl;
     if (_creating)
     {
-       //qDebug() << "DXCCStatusWidget::setBands (creating true) " << QString::number(_ent.length()) << endl;
+      //qDebug() << "DXCCStatusWidget::setBands (creating true) " << QString::number(_ent.length()) << endl;
     }
     else
     {
-       //qDebug() << "DXCCStatusWidget::setBands (creating false) " << QString::number(_ent.length()) << endl;
+      //qDebug() << "DXCCStatusWidget::setBands (creating false) " << QString::number(_ent.length()) << endl;
     }
 
     QStringList qs;
     qs.clear();
-    //qDebug() << "DXCCStatusWidget::setBands - 1 " << endl;
+   //qDebug() << "DXCCStatusWidget::setBands - 1 " << endl;
     qs << dataProxy->sortBandNamesBottonUp(_ent);
-    //qDebug() << "DXCCStatusWidget::setBands - 2 " << endl;
+   //qDebug() << "DXCCStatusWidget::setBands - 2 " << endl;
     if (qs.length()<0)
     {
-        //qDebug() << "DXCCStatusWidget::setBands no bands received here " << endl;
+       //qDebug() << "DXCCStatusWidget::setBands no bands received here " << endl;
         return;
     }
 
@@ -239,11 +248,11 @@ void DXCCStatusWidget::setBands(QStringList const _ent, const bool _creating)
 
     bandNames.clear();
     //bandNames << "Id" << "Entity";
-   //qDebug() << "DXCCStatusWidget::setBands - 3 " << endl;
+    //qDebug() << "DXCCStatusWidget::setBands - 3 " << endl;
     validBands.clear();
     //validBands << dataProxy->getBands();
     validBands << dataProxy->getBandNames();
-    //qDebug() << "DXCCStatusWidget::setBands - 4 " << endl;
+     //qDebug() << "DXCCStatusWidget::setBands - 4 " << endl;
     dxccView->clearContents();    
    // for (int x = 0; x < dxccView->columnCount(); x++)
    // {
@@ -253,20 +262,20 @@ void DXCCStatusWidget::setBands(QStringList const _ent, const bool _creating)
     //bands.clear();
     for (int i = 0; i<qs.length(); i++)
     {
-        //qDebug() << "DXCCStatusWidget::setBands-1: " << qs.at(i) << endl;
+       //qDebug() << "DXCCStatusWidget::setBands-1: " << qs.at(i) << endl;
         testBand = qs.at(i);
 
         if (validBands.contains(qs.at(i)))
         {
             bandNames.append(testBand);
-           //qDebug() << "DXCCStatusWidget::setBands-2: Added: " << bandNames.last()  << endl;
+            //qDebug() << "DXCCStatusWidget::setBands-2: Added: " << bandNames.last()  << endl;
         }
         else
         {
-         //qDebug() << "DXCCStatusWidget::setBands: Not valid band: " << testBand << endl;
+          //qDebug() << "DXCCStatusWidget::setBands: Not valid band: " << testBand << endl;
         }
     }
-   //qDebug() << "DXCCStatusWidget::setBands - 5 " << endl;
+  //qDebug() << "DXCCStatusWidget::setBands - 5 " << endl;
 
     numberOfColumns = 2 + bandNames.length();
     dxccView->setColumnCount(numberOfColumns);  
@@ -277,21 +286,22 @@ void DXCCStatusWidget::setBands(QStringList const _ent, const bool _creating)
     headerqs << tr("ID") << tr("Entity") << bandNames;
     dxccView->setHorizontalHeaderLabels(headerqs);
 
-   //qDebug() << "DXCCStatusWidget::setBands: PRE-END" << endl;
+  //qDebug() << "DXCCStatusWidget::setBands: PRE-END" << endl;
 
     if (!_creating)
     {
+        //qDebug() << "DXCCStatusWidget::setBands: !_creating" << endl;
         update();
     }
 
-   //qDebug() << "DXCCStatusWidget::setBands: END" << endl;
+  //qDebug() << "DXCCStatusWidget::setBands: END" << endl;
 
 
 }
 
 void DXCCStatusWidget::setDefaultBands()
 {
-   //qDebug() << "DXCCStatusWidget::setDefaultBands" << endl;
+    //qDebug() << "DXCCStatusWidget::setDefaultBands" << endl;
     /*
      Default bands:
      160M    80M  40M  30M  20M  17M  15M  12M  10M  6M   4M   2M   70CM
@@ -307,7 +317,7 @@ void DXCCStatusWidget::setDefaultBands()
 
 void DXCCStatusWidget::slotRefreshButtonClicked()
 {
-  //qDebug() << "DXCCStatusWidget::slotRefreshButtonClicked" << endl;
+   //qDebug() << "DXCCStatusWidget::slotRefreshButtonClicked" << endl;
     //TODO: Define a way to show the status of the selected log or all the logs in the DB
     QStringList _bands = bandNames;
     setBands(_bands);
@@ -317,13 +327,13 @@ void DXCCStatusWidget::slotRefreshButtonClicked()
 
 void DXCCStatusWidget::refresh()
 {
-   //qDebug() << "DXCCStatusWidget::refresh" << endl;
+    //qDebug() << "DXCCStatusWidget::refresh" << endl;
     slotRefreshButtonClicked();
 }
 
  void DXCCStatusWidget::setCurrentLog(const int _logN)
  {
-    //qDebug() << "DXCCStatusWidget::setCurrentLog: " << QString::number(_logN) << endl;
+     //qDebug() << "DXCCStatusWidget::setCurrentLog: " << QString::number(_logN) << endl;
      if (dataProxy->doesThisLogExist(_logN))
      {
          logNumber = _logN;
@@ -336,8 +346,8 @@ void DXCCStatusWidget::refresh()
 
  void DXCCStatusWidget::slotItemEntered(QTableWidgetItem  * item )
  {
-    //qDebug() << "DXCCStatusWidget::slotItemEntered: " << ((item->data(0)).toString()).simplified() << endl;
-    //qDebug() << "DXCCStatusWidget::slotItemEntered: " << item->text() << endl;
+     //qDebug() << "DXCCStatusWidget::slotItemEntered: " << ((item->data(0)).toString()).simplified() << endl;
+     //qDebug() << "DXCCStatusWidget::slotItemEntered: " << item->text() << endl;
     QString tip;
     tip.clear();
     int row = -1;
@@ -351,10 +361,10 @@ void DXCCStatusWidget::refresh()
         column = dxccView->column(item);
 
 
-        //qDebug() << "DXCCStatusWidget::slotItemEntered: row: " << QString::number(row) << endl;
-        //qDebug() << "DXCCStatusWidget::slotItemEntered: hrow: " <<  dxccView->verticalHeaderItem(row)->text() << endl;
+         //qDebug() << "DXCCStatusWidget::slotItemEntered: row: " << QString::number(row) << endl;
+         //qDebug() << "DXCCStatusWidget::slotItemEntered: hrow: " <<  dxccView->verticalHeaderItem(row)->text() << endl;
         row = (dxccView->item(row,0)->text()).toInt();
-        //qDebug() << "DXCCStatusWidget::slotItemEntered: column: " << QString::number(column) << endl;
+         //qDebug() << "DXCCStatusWidget::slotItemEntered: column: " << QString::number(column) << endl;
         if (column >= 2)
         {
             if (item->text() == "-")
@@ -364,11 +374,11 @@ void DXCCStatusWidget::refresh()
             else
             {
                 band = dxccView->horizontalHeaderItem(column)->text();
-                //qDebug() << "DXCCStatusWidget::slotItemEntered: band: " << band << endl;
+                 //qDebug() << "DXCCStatusWidget::slotItemEntered: band: " << band << endl;
                 bandi = dataProxy->getIdFromBandName(band);
-                //qDebug() << "DXCCStatusWidget::slotItemEntered: band: " << QString::number(bandi) << endl;
+                 //qDebug() << "DXCCStatusWidget::slotItemEntered: band: " << QString::number(bandi) << endl;
                 tip = awards->getQSOofAward(row, bandi);
-                //qDebug() << "DXCCStatusWidget::slotItemEntered: tip: " << tip << endl;
+                 //qDebug() << "DXCCStatusWidget::slotItemEntered: tip: " << tip << endl;
                 if (tip.length()>3)
                 {
                     tip = "QSO: " + tip;
@@ -389,23 +399,23 @@ void DXCCStatusWidget::refresh()
         }
 
         item->setToolTip(tip);
-        //qDebug() << "DXCCStatusWidget::slotItemEntered: tip: " << tip << endl;
+         //qDebug() << "DXCCStatusWidget::slotItemEntered: tip: " << tip << endl;
 
 
     }
     else
     {}
 
-   //qDebug() << "DXCCStatusWidget::slotItemEntered: END " << endl;
+    //qDebug() << "DXCCStatusWidget::slotItemEntered: END " << endl;
 
  }
 
 void DXCCStatusWidget::slotItemDoubleClicked(QTableWidgetItem  * item )
 {
 
-    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: " << ((item->data(0)).toString()).simplified() << endl;
-    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: " << item->text() << endl;
-    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked - start" << endl;
+     //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: " << ((item->data(0)).toString()).simplified() << endl;
+     //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: " << item->text() << endl;
+     //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked - start" << endl;
     int row = -1;
     int column = -1;
     int qsoId = -1;
@@ -420,62 +430,62 @@ void DXCCStatusWidget::slotItemDoubleClicked(QTableWidgetItem  * item )
     QTableWidgetItem * it = new QTableWidgetItem(0);
     //it->setText(item->data(Qt::DisplayRole));
 
-    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - 01"  << endl;
+     //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - 01"  << endl;
     if (item)
     {
         row = dxccView->row(item);
         column = dxccView->column(item);
 
 
-        //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: row: " << QString::number(row) << endl;
-        //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: column: " << QString::number(column) << endl;
+         //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: row: " << QString::number(row) << endl;
+         //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: column: " << QString::number(column) << endl;
 
         //if (column == 1)
         if (true)
         {
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column = 1"  << endl;
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column header: " << dxccView->horizontalHeaderItem(column)->text() << endl;
+             //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column = 1"  << endl;
+             //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column header: " << dxccView->horizontalHeaderItem(column)->text() << endl;
             _entiNumb = ((dxccView->item(row,0))->text()).toInt();
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - EntityNumber: " << QString::number(_entiNumb) << endl;
+             //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - EntityNumber: " << QString::number(_entiNumb) << endl;
 
             for (int i = 2; i < columns; ++i)
             {
-                //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column: "  << QString::number(i) << endl;
-                //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column header: " << (dxccView->horizontalHeaderItem(i))->text() << endl;
+                 //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column: "  << QString::number(i) << endl;
+                 //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column header: " << (dxccView->horizontalHeaderItem(i))->text() << endl;
                 //entityName = (dxccView->item(row,i))->text() ;
-                //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - item: "  << entityName << endl
+                 //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - item: "  << endl;
 
 
                it->setText(dxccView->item(row,i)->text());
-               //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column-txt: "  << it->text() << endl;
+                //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column-txt: "  << it->text() << endl;
 
                band = dxccView->horizontalHeaderItem(i)->text();
-               //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: band: " << band << endl;
+                //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: band: " << band << endl;
                bandi = dataProxy->getIdFromBandName(band);
-               //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: band: " << QString::number(bandi) << endl;
+                //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: band: " << QString::number(bandi) << endl;
                qsoId = awards->getQSOIdofAward(_entiNumb, bandi);
-               //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: QSOid: " << QString::number(qsoId) << endl;
+                //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: QSOid: " << QString::number(qsoId) << endl;
                if (qsoId>0)
                {
                    qsos.append(qsoId);
                }
 
             }
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - END of for"  << endl;
+             //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - END of for"  << endl;
             if (qsos.length()>0)
             {
-                //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - qsos.length = " << QString::number(qsos.length())  << endl;
+                 //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - qsos.length = " << QString::number(qsos.length())  << endl;
                 emit showQsos(qsos);
             }
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - END of column == 1"  << endl;
+             //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - END of column == 1"  << endl;
         }
         else
         {
-            //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column != 1"  << endl;
+             //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: - column != 1"  << endl;
             //tip = ""; // TODO define a text to be shown when no band column is selected (maybe Continent & bearing or a link to wikipedia or whatever!)
         }
     }
 
 
-    //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: END " << endl;
+     //qDebug() << "DXCCStatusWidget::slotItemDoubleClicked: END " << endl;
 }
