@@ -49,10 +49,16 @@ public:
     void refresh();
 
 signals:
+    void showQso(const int _qsoid); // identified QSO double clicking on DXCC
+    void showQsos(QList<int> _qsos);
+    //void updateAwards();
 
 public slots:
     //void slotSearchLineEditTextChanged();
     void slotRefreshButtonClicked();
+    void slotItemEntered(QTableWidgetItem  * item );
+    void slotItemDoubleClicked(QTableWidgetItem  * item );
+
 private:
     void createUI();
     void setDefaultBands();
