@@ -28,20 +28,19 @@ email                : jaime@robles.es
 DXClusterWidget::DXClusterWidget(DataProxy *dp, QWidget *parent)
           : QWidget(parent)
 {
-    //qDebug() << "DXClusterWidget::DXClusterWidget" << endl;
+     //qDebug() << "DXClusterWidget::DXClusterWidget" << endl;
     dataProxy = dp;
     constrid = 1;
     awards = new Awards(dataProxy);
 
-
     initClass();
-    //qDebug() << "DXClusterWidget::DXClusterWidget - END" << endl;
+     //qDebug() << "DXClusterWidget::DXClusterWidget - END" << endl;
 }
 
 DXClusterWidget::DXClusterWidget(DataProxy *dp, const QString &clusterToConnect, const int portToConnect, QWidget *parent)
           : QWidget(parent)
 {
-   //qDebug() << "DXClusterWidget::DXClusterWidget2" << clusterToConnect << QString::number(portToConnect) << endl;
+    //qDebug() << "DXClusterWidget::DXClusterWidget2" << clusterToConnect << QString::number(portToConnect) << endl;
    constrid = 2;
 
     initClass();
@@ -99,7 +98,7 @@ DXClusterWidget::DXClusterWidget(DataProxy *dp, const QString &clusterToConnect,
     addData();
 
      //TESTADDSPOT();
-    //qDebug() << "DXClusterWidget::DXClusterWidget2 - END"  << endl;
+     //qDebug() << "DXClusterWidget::DXClusterWidget2 - END"  << endl;
 
 }
 
@@ -131,7 +130,7 @@ void DXClusterWidget::setMyQRZ(const QString _qrz)
 
 void DXClusterWidget::addData()
 {
-    //qDebug() << "DXClusterWidget::addData " << endl;
+     //qDebug() << "DXClusterWidget::addData " << endl;
 
     /*
                 QTreeWidgetItem *item = new QTreeWidgetItem(searchResultsTreeWidget);
@@ -154,13 +153,13 @@ void DXClusterWidget::addData()
 
 DXClusterWidget::~DXClusterWidget()
 {
-    //qDebug() << "DXClusterWidget::~DXClusterWidget" << endl;
+     //qDebug() << "DXClusterWidget::~DXClusterWidget" << endl;
 }
 
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetItem * item )
 {
-   //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: " << item->text() << endl;
+    //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: " << item->text() << endl;
 
     QStringList ql;
     ql.clear();
@@ -168,31 +167,31 @@ void DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked( QListWidgetIt
     if (item)
     {
         ql = readItem(item);
-        //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Length: " << QString::number(ql.length())  << endl;
+         //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Length: " << QString::number(ql.length())  << endl;
         if (ql.length()==2)
         {
             ql << "double";
-            //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: EMMITED"  << endl;
+             //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: EMMITED"  << endl;
             emit dxspotclicked(ql);
         }
         else
         {
-            //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-1"  << endl;
+             //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-1"  << endl;
         }
     }
     else
     {
-        //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-2 (no item)"  << endl;
+         //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: NOT EMMITED-2 (no item)"  << endl;
     }
 
 }
 
 void DXClusterWidget::connectToDXCluster()
 {
-    //qDebug() << "DXClusterWidget::connectToDXCluster" << endl;
+     //qDebug() << "DXClusterWidget::connectToDXCluster" << endl;
     if (dxClusterConnected)
     {
-        //qDebug() << "DXClusterWidget::connectToDXCluster: - Already connected!!" << endl;
+         //qDebug() << "DXClusterWidget::connectToDXCluster: - Already connected!!" << endl;
         return; // If we are connected we don't want to start another connection
     }
 
@@ -212,7 +211,7 @@ void DXClusterWidget::connectToDXCluster()
 
 void DXClusterWidget::slotClusterDisplayError(QAbstractSocket::SocketError socketError)
 {
-    //qDebug() << "DXClusterWidget:displayError:" << endl;
+     //qDebug() << "DXClusterWidget:displayError:" << endl;
      switch (socketError) {
      case QAbstractSocket::RemoteHostClosedError:
          break;
@@ -239,74 +238,74 @@ void DXClusterWidget::slotClusterDisplayError(QAbstractSocket::SocketError socke
 
 bool DXClusterWidget::checkIfNeedsToBePrinted(const QString _DXEntity, int const _band, const int _mode)
 {
-    //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: " << _dxCall << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+    //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: " << _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
     QStringList qs;
     qs.clear();
     qs << _DXEntity << QString::number(_band) << QString::number(_mode)  << QString::number(currentLog);
     //bool isConfirmed = false;
     bool status = awards->isThisSpotConfirmed (qs);
 
-   //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Status: " << _dxCall << "/" << QString::number(status);
+    //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Status: " << _DXEntity << "/" << QString::number(status);
 
     if (!showconfirmed)
     {
-       //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is confirmed? ("<< QString::number(status)<< ")" << endl;
+        //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is confirmed? ("<< QString::number(status)<< ")" << endl;
         if (status)
         {
-           //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: It is confirmed: DON'T' print: " << _dxCall <<"/" << dataProxy->getNameFromBandId(_band) << endl;
+            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: It is confirmed: DON'T' print: " << _DXEntity <<"/" << dataProxy->getNameFromBandId(_band) << endl;
             return false;
         }
     }
 
     if (!showhf)
     {
-       //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF?" << endl;
+        //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF?" << endl;
         if (dataProxy->isHF(_band))
         {
-           //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is it WARC?" << endl;
+            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is it WARC?" << endl;
             if ( (showwarc) && dataProxy->isWARC(_band) )
             {
-               //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is WARC, print!" << endl;
+                //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: Not showing HF but... is WARC, print!" << endl;
                 return true;
             }
 
-           //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF: DON'T print: "<< _dxCall << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is HF: DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
             return false;
         }
         else
         {
-           //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT HF" << endl;
+            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT HF" << endl;
         }
     }
 
     if (!showwarc)
     {
-       //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC?" << endl;
+        //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC?" << endl;
         if (dataProxy->isWARC(_band))
         {
-           //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC, DON'T print: "<< _dxCall << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is WARC, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
             return false;
         }
         else
         {
-           //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT WARC" << endl;
+            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT WARC" << endl;
         }
     }
 
     if (!showvhf)
     {
-        //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF?" << endl;
+         //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF?" << endl;
         if (dataProxy->isVHF(_band))
         {
-            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF, DON'T print: "<< _dxCall << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+             //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is VHF, DON'T print: "<< _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
             return false;
         }
         else
         {
-            //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT VHF " << endl;
+             //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: is NOT VHF " << endl;
         }
     }
-    //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: returns TRUE and will be printed: " << _dxCall << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
+     //qDebug() << "DXClusterWidget::checkIfNeedsToBePrinted: returns TRUE and will be printed: " << _DXEntity << "/" << dataProxy->getNameFromBandId(_band) << QString::number(_mode)<< endl;
     return true;
 }
 
@@ -325,7 +324,7 @@ void DXClusterWidget::setCurrentLog(const int _log)
 
 void DXClusterWidget::slotClusterDataArrived()
 {
-   //qDebug() << "DXClusterWidget::slotClusterDataArrived" << endl;
+    //qDebug() << "DXClusterWidget::slotClusterDataArrived" << endl;
     QStringList qs;
     QString dxClusterString;
     QString dxCall;
@@ -345,11 +344,11 @@ void DXClusterWidget::slotClusterDataArrived()
         }
         // It is a "DX de SP0TTER FREC DXCALL"
         //0 = DX, 1 = de, 2 = spotter, 3 = Freq, 4 = dxcall, 5 = comment
-       //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << "DXCLUSTER->" << dxClusterString << "\nTOKENS: " << tokens << endl;
+        //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << "DXCLUSTER->" << dxClusterString << "\nTOKENS: " << tokens << endl;
 
         if ((tokens[0] == "DX") && (tokens[1] == "de"))
         {
-           //qDebug() << "******************** DXClusterWidget::slotClusterDataArrived: DX DE" << endl;
+            //qDebug() << "******************** DXClusterWidget::slotClusterDataArrived: DX DE" << endl;
             //isADXSpot = true;
             QString spotter = tokens[2];
             spotter.truncate(spotter.size() - 1);
@@ -366,7 +365,7 @@ void DXClusterWidget::slotClusterDataArrived()
             qs.clear();
             //spotBand = QString::number(world->getBandIdFromFreq(  dxFrequency  ) );
             qs << QString::number(dxEntity) << spotBand << "-1" << QString::number(currentLog) ;
-            //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-2: " << QString::number(dxEntity) << endl;
+             //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-2: " << QString::number(dxEntity) << endl;
             dxSpotColor = awards->getQRZDXStatusColor(qs);
 
             if (awards->isDXMarathonNeed(dxEntity, world->getQRZCqz(dxCall), QDateTime::currentDateTime().date().year(), currentLog))
@@ -374,19 +373,19 @@ void DXClusterWidget::slotClusterDataArrived()
                 dxClusterString = dxClusterString + "  ### Needed for DXMarathon - " + QString::number(QDateTime::currentDateTime().date().year()) + " ###";
             }
 
-           //qDebug() << "DX de ->" << "Spotter: " << spotter << "Freq: "<< dxFrequency << "DX: " << dxCall << endl;
+            //qDebug() << "DX de ->" << "Spotter: " << spotter << "Freq: "<< dxFrequency << "DX: " << dxCall << endl;
 
         }
         else if ((tokens[0] == "To") && (tokens[1] == "ALL"))
         {
-           //qDebug() << "DXClusterWidget::slotClusterDataArrived: TO ALL" << endl;
+            //qDebug() << "DXClusterWidget::slotClusterDataArrived: TO ALL" << endl;
             dxSpotColor = awards->getDefaultColor();
         }
         else if ( (dxClusterString.length()>=5) && (world->checkQRZValidFormat(tokens[1])) && (tokens[0]!="login:"))
         { // Freq / DXCall / Date // time
            //_qs << QRZ << Freq in MHz << lognumber;
-          //qDebug() << "DXClusterWidget::slotClusterDataArrived: LENGTH >= 5" << endl;
-          //qDebug() << "DXClusterWidget::slotClusterDataArrived: token0=" << tokens[0] << " / token1=" << tokens[1] << endl;
+           //qDebug() << "DXClusterWidget::slotClusterDataArrived: LENGTH >= 5" << endl;
+           //qDebug() << "DXClusterWidget::slotClusterDataArrived: token0=" << tokens[0] << " / token1=" << tokens[1] << endl;
 
             //isADXSpot = true;
             dxCall = tokens[1];
@@ -396,7 +395,7 @@ void DXClusterWidget::slotClusterDataArrived()
             qs.clear();
             spotBand = QString::number(dataProxy->getBandIdFromFreq(  dxFrequency.toDouble()  ) );
             dxEntity = world->getQRZARRLId(dxCall);
-            //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-1: " << QString::number(dxEntity) << endl;
+             //qDebug() << "DXClusterWidget::slotClusterDataArrived: Calling-1: " << QString::number(dxEntity) << endl;
             qs << QString::number(dxEntity) << spotBand << "-1" << QString::number(currentLog) ;
             dxSpotColor = awards->getQRZDXStatusColor(qs);
 
@@ -407,7 +406,7 @@ void DXClusterWidget::slotClusterDataArrived()
         }
         else
         {
-            //qDebug() << "DXClusterWidget::slotClusterDataArrived: DEFAULT" << endl;
+             //qDebug() << "DXClusterWidget::slotClusterDataArrived: DEFAULT" << endl;
             dxSpotColor = awards->getDefaultColor();
         }
 
@@ -416,12 +415,12 @@ void DXClusterWidget::slotClusterDataArrived()
         //qs << dxCall << spotBand << "0";
 
         //dxSpotColor = awards->getQRZDXStatusColor(qs);
-        //qDebug() << "DXClusterWidget::slotClusterDataArrived: Call/dxSpotColor: " << dxCall <<"/"<< dxSpotColor.name() << endl;
+         //qDebug() << "DXClusterWidget::slotClusterDataArrived: Call/dxSpotColor: " << dxCall <<"/"<< dxSpotColor.name() << endl;
         //dxClusterSpotItem * item = new dxClusterSpotItem(dxClusterListWidget, dxClusterString, dxSpotColor);
         //TODO: Change the "-1" by the mode
         if (!checkIfNeedsToBePrinted(QString::number(dxEntity), spotBand.toInt(), -1))
         {
-           //qDebug() << "DXClusterWidget::slotClusterDataArrived - Not to be printed!: " << dxCall << endl;
+            //qDebug() << "DXClusterWidget::slotClusterDataArrived - Not to be printed!: " << dxCall << endl;
             return;
         }
 
@@ -462,15 +461,15 @@ void DXClusterWidget::slotClusterDataArrived()
         //dxClusterListWidget->insertItem(0,item);
     }
 
-    //qDebug() << "--------------------- DXClusterWidget::slotClusterDataArrived: " << dxClusterString << endl;
+     //qDebug() << "--------------------- DXClusterWidget::slotClusterDataArrived: " << dxClusterString << endl;
 
-   //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << dxClusterString << endl;
+    //qDebug() << "DXClusterWidget::slotClusterDataArrived: " << dxClusterString << endl;
 
 }
 
 void DXClusterWidget::slotClusterSocketConnected()
 {
-    //qDebug() << "DXClusterWidget::slotClusterSocketConnected" << endl;
+     //qDebug() << "DXClusterWidget::slotClusterSocketConnected" << endl;
 
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(awards->getDefaultColor()));
@@ -508,14 +507,14 @@ void DXClusterWidget::slotClusterSocketConnected()
             dxClusterAlreadyConnected = false;
         }
         inputCommand->setEnabled(true);
-        inputCommand->setToolTip(tr("Enter here the commands to be sent to the DX-Cluster server"));
+        inputCommand->setToolTip(tr("Enter here the commands to be sent to the DX-Cluster server."));
 
     }
 }
 
 void DXClusterWidget::slotClusterSocketConnectionClosed()
 {
-    //qDebug() << "DXClusterWidget::slotClusterSocketConnectionClosed" << endl;
+     //qDebug() << "DXClusterWidget::slotClusterSocketConnectionClosed" << endl;
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(awards->getDefaultColor()));
     item->setText(tr("Connection closed by the server"));
@@ -524,14 +523,14 @@ void DXClusterWidget::slotClusterSocketConnectionClosed()
     dxClusterAlreadyConnected = false;
     sendButton->setText(tr("Connect"));
     inputCommand->setDisabled(true);
-    inputCommand->setToolTip(tr("Click on Connect to connect to the DX-Cluster server"));
+    inputCommand->setToolTip(tr("Click on Connect to connect to the DX-Cluster server."));
     //connect(inputCommand, SIGNAL(returnPressed()), this, SLOT(slotClusterSendToServer()) );
     disconnect (inputCommand, SIGNAL(returnPressed()), this, SLOT(slotClusterSendToServer()) );
 }
 
 void DXClusterWidget::slotClusterSendToServer()
 {
-    //qDebug() << "DXClusterWidget::slotClusterSendToServer()" << endl;
+     //qDebug() << "DXClusterWidget::slotClusterSendToServer()" << endl;
     if (!dxClusterConnected)
     {
 
@@ -540,7 +539,7 @@ void DXClusterWidget::slotClusterSendToServer()
     }
     if ( inputCommand ->text().length() < 1 )
     {
-        //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Vacio..." << endl;
+         //qDebug() << "DXClusterWidget::slotClusterSendToServer() - Vacio..." << endl;
         QTextStream os(tcpSocket);
         os << "bye\n";
         return;
@@ -553,7 +552,7 @@ void DXClusterWidget::slotClusterSendToServer()
 
 void DXClusterWidget::slotClusterClearLineInput()
 {
-    //qDebug() << "DXClusterWidget::slotClusterClearLineInput" << endl;
+     //qDebug() << "DXClusterWidget::slotClusterClearLineInput" << endl;
 
     if ( ((inputCommand->text()).length()) <= 0 )
     {
@@ -575,7 +574,7 @@ void DXClusterWidget::slotClusterClearLineInput()
 
 void DXClusterWidget::slotClusterInputTextChanged()
 {
-    //qDebug() << "DXClusterWidget::slotClusterInputTextChanged" << endl;
+     //qDebug() << "DXClusterWidget::slotClusterInputTextChanged" << endl;
 
     if ( ((inputCommand->text()).length()) <= 0 )
     {
@@ -593,7 +592,7 @@ void DXClusterWidget::slotClusterInputTextChanged()
 
 void DXClusterWidget::setColors (const QString _newOne, const QString _needed, const QString _worked, const QString _confirmed, const QString _default)
 {
-    //qDebug() << "DXClusterWidget::setColors: " << _newOne << "/" << _needed << "/" << _worked << "/" << _confirmed << "/" << _default << endl;
+     //qDebug() << "DXClusterWidget::setColors: " << _newOne << "/" << _needed << "/" << _worked << "/" << _confirmed << "/" << _default << endl;
     // Just to pass the colors to the awards class
     awards->setColors(_newOne,  _needed, _worked,  _confirmed, _default);
 
@@ -601,7 +600,7 @@ void DXClusterWidget::setColors (const QString _newOne, const QString _needed, c
 
 void DXClusterWidget::setDXClusterSpotConfig(bool _showhf, bool _showvhf, bool _showwarc, bool _showworked, bool _showconfirmed, bool _showann, bool _showwwv, bool _showwcy )
 {
-    //qDebug() << "DXClusterWidget::setDXClusterSpotConfig " << endl;
+     //qDebug() << "DXClusterWidget::setDXClusterSpotConfig " << endl;
 
     showhf = _showhf;
     showvhf = _showvhf;
@@ -615,7 +614,7 @@ void DXClusterWidget::setDXClusterSpotConfig(bool _showhf, bool _showvhf, bool _
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemSelected()
 {
-    //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemSelected " << endl;
+     //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemSelected " << endl;
     QListWidgetItem * item = dxClusterListWidget->currentItem();
 
     QStringList ql;
@@ -635,7 +634,7 @@ void DXClusterWidget::slotClusterDXClusterWidgetItemSelected()
 
 void DXClusterWidget::slotClusterDXClusterWidgetItemEntered( QListWidgetItem * item )
 {
-    //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemEntered" << endl;
+     //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemEntered" << endl;
 /*
     This code comes from slotClusterDXClusterWidgetItemDoubleClicked
 */
@@ -670,7 +669,7 @@ bool DXClusterWidget::isConnected()
 
 QStringList DXClusterWidget::readItem(QListWidgetItem * item)
 {
-    //qDebug() << "DXClusterWidget::readItem" << endl;
+     //qDebug() << "DXClusterWidget::readItem" << endl;
 
     QStringList fields;
     QString dxClusterString;
@@ -691,7 +690,7 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
 
             if ( world->getQRZARRLId(fields.at(4))> 0 )
             {
-                //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: ARRLid: " << QString::number(world->getQRZARRLId(fields.at(4)))  << endl;
+                 //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: ARRLid: " << QString::number(world->getQRZARRLId(fields.at(4)))  << endl;
                 dxCallsign = (fields.at(4)).toUpper();
                 (fields.at(3)).toFloat(&FirstFrecOK);
                 if (FirstFrecOK)
@@ -713,7 +712,7 @@ QStringList DXClusterWidget::readItem(QListWidgetItem * item)
             else
             { // The call is not from a valid country
               // TODO: if it is from a new entity/prefix it would not work.
-                //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Entity not valid"  << endl;
+                 //qDebug() << "DXClusterWidget::slotClusterDXClusterWidgetItemDoubleClicked: Entity not valid"  << endl;
                 dxCallsign.clear();
                 dxFreq.clear();
                 fields.clear();
@@ -748,13 +747,13 @@ void DXClusterWidget::setDXClusterServer(const QString &clusterToConnect, const
 {
     server = clusterToConnect;
     port = portToConnect;
-    //qDebug() << "DXClusterWidget::setDXClusterServer: " << server << ":"<< QString::number(port)  << endl;
+     //qDebug() << "DXClusterWidget::setDXClusterServer: " << server << ":"<< QString::number(port)  << endl;
 }
 
 /*
 void DXClusterWidget::TESTADDSPOT()
 {
-    //qDebug() << "DXClusterWidget::TESTADDSPOT "   << endl;
+     //qDebug() << "DXClusterWidget::TESTADDSPOT "   << endl;
     ; // Just a test spot
     QListWidgetItem *item = new QListWidgetItem();
     item->setForeground(QBrush(dxSpotColor));
@@ -768,7 +767,7 @@ void DXClusterWidget::TESTADDSPOT()
 ** It may be moved to a self .h & .cpp archives                           **
 ****************************************************************************/
 dxClusterSpotItem::dxClusterSpotItem( QListWidget *parent, const QString& spot, const QColor& color ) : QListWidgetItem( parent ){
-    //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Constructor" << endl;
+     //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Constructor" << endl;
     spotColor = color;
     setText(spot);
     // Experimenting with fonts for the cluster
@@ -779,6 +778,6 @@ dxClusterSpotItem::dxClusterSpotItem( QListWidget *parent, const QString& spot,
 
 dxClusterSpotItem::~dxClusterSpotItem()
 {
-    //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Destructor" << endl;
+     //qDebug() << "dxClusterSpotItem::dxClusterSpotItem - Destructor" << endl;
 }
 
