@@ -29,12 +29,12 @@
 
 LogWindow::LogWindow(DataProxy *dp, QWidget *parent) : QWidget(parent)
 {
-   //qDebug() << "LogWindow::LogWindow: "  << endl;
+    //qDebug() << "LogWindow::LogWindow: "  << endl;
     dataProxy = dp;
     logModel = new LogModel(dataProxy, this);
     connect(logModel, SIGNAL(queryError(QString, QString, int, QString)), this, SLOT(slotQueryErrorManagement(QString, QString, int, QString)) );
     logView = new QTableView;
-    dxccStatusWidget = new DXCCStatusWidget(dataProxy);
+    //dxccStatusWidget = new DXCCStatusWidget(dataProxy);
     elogClublog = new eLogClubLog();
 
     currentLog = -1;
@@ -45,24 +45,24 @@ LogWindow::LogWindow(DataProxy *dp, QWidget *parent) : QWidget(parent)
     createUI();
     createActions();
     setDefaultData();
-    //qDebug() << "LogWindow::LogWindow: - END"  << endl;
+     //qDebug() << "LogWindow::LogWindow: - END"  << endl;
 
 }
 
 LogWindow::~LogWindow()
 {
-
+//    emit clearError();
 }
 
 
 void LogWindow::clear()
 {
-   //qDebug() << "LogWindow::clear "  << endl;
+    //qDebug() << "LogWindow::clear "  << endl;
 }
 
 void LogWindow::createUI()
 {
-   //qDebug() << "LogWindow::createUI"  << endl;
+    //qDebug() << "LogWindow::createUI"  << endl;
 
     logView->setContextMenuPolicy(Qt::CustomContextMenu);
     logView->setSortingEnabled(true);
@@ -75,37 +75,35 @@ void LogWindow::createUI()
 void LogWindow::setDefaultData()
 {
 
-    //qDebug() << "LogWindow::setDefaultData"  << endl;
+     //qDebug() << "LogWindow::setDefaultData"  << endl;
 }
 
 
 void LogWindow::createlogPanel(const int _currentLog)
 {
-   //qDebug() << "LogWindow::createlogPanel: " << QString::number(_contestID) << endl;
+    //qDebug() << "LogWindow::createlogPanel: " << QString::number(_currentLog) << endl;
     currentLog = _currentLog;
     logModel->createlogModel(currentLog);
     logView->setModel(logModel);
     logView->setCurrentIndex(logModel->index(0, 0));
 
-
-
     QString contestMode = dataProxy->getLogTypeOfUserLog(currentLog);
 
     if (contestMode == "DX")
     {
-        //qDebug() << "LogWindow::createlogPanel: DX"  << endl;
+         //qDebug() << "LogWindow::createlogPanel: DX"  << endl;
         setColumnsToDX();
     }
     else if (contestMode == "CQ-WW-SSB")
     {
-        //qDebug() << "LogWindow::createlogPanel: CQ-WW-SSB"  << endl;
+         //qDebug() << "LogWindow::createlogPanel: CQ-WW-SSB"  << endl;
     }
 
     else
     {
         // THIS POINT SHOULD NOT BE REACHED. It means that there is a kind of contest not supported.
         // Maybe the way should be to move ALL the actions from DX here.
-        //qDebug() << "LogWindow::createlogPanel: No log type found!"  << endl;
+         //qDebug() << "LogWindow::createlogPanel: No log type found!"  << endl;
     }
 
     logView->setItemDelegate(new QSqlRelationalDelegate(this));
@@ -118,7 +116,7 @@ void LogWindow::createlogPanel(const int _currentLog)
 
 void LogWindow::setColumnsToDX()
 {
-   //qDebug() << "LogWindow::setColumnsToDX"  << endl;
+    //qDebug() << "LogWindow::setColumnsToDX"  << endl;
     QString stringQuery;
     stringQuery = QString("SELECT * FROM log LIMIT 1");
     QSqlQuery query;
@@ -157,9 +155,10 @@ void LogWindow::setColumnsToDX()
 
 void LogWindow::refresh()
 {
+     //qDebug() << "LogWindow::refresh"  << endl;
     logModel->select();
 }
-;
+
 void LogWindow::createActions()
 {
     createActionsCommon();
@@ -171,12 +170,11 @@ void LogWindow::createActionsCommon()
 
         connect(logView, SIGNAL(customContextMenuRequested( const QPoint& ) ), this, SLOT(slotRighButtonFromLog( const QPoint& ) ) );
         connect(logView, SIGNAL(doubleClicked ( const QModelIndex& ) ), this, SLOT(slotDoubleClickLog( const QModelIndex& ) ) );
-
 }
 
 void LogWindow::slotRighButtonFromLog(const QPoint& pos)
 {
-    //qDebug() << "LogWindow::slotshowRighButtonFromLog"  << endl;
+     //qDebug() << "LogWindow::slotshowRighButtonFromLog"  << endl;
     int row = (logView->indexAt(pos)).row();
     showMenuRightButtonFromLogCreateActions();
     righButtonFromLogMenu(row);
@@ -185,10 +183,10 @@ void LogWindow::slotRighButtonFromLog(const QPoint& pos)
 
 void LogWindow::righButtonFromLogMenu(const int trow)
 {
-    //qDebug() << "LogWindow::slotshowRighButtonFromLogMenu:  " << QString::number(trow) << endl;
+     //qDebug() << "LogWindow::slotshowRighButtonFromLogMenu:  " << QString::number(trow) << endl;
 
     int _qsoID = ((logModel->index(trow, 0)).data(0)).toInt();
-    //qDebug() << "LogWindow::slotshowRighButtonFromLogMenu:  QSOid: " << QString::number(_qsoID) << endl;
+     //qDebug() << "LogWindow::slotshowRighButtonFromLogMenu:  QSOid: " << QString::number(_qsoID) << endl;
     bool qslReceived = isQSLReceived(_qsoID);
     bool qslSent = isQSLSent(_qsoID);
     QMenu menu(this);
@@ -243,14 +241,14 @@ void LogWindow::righButtonFromLogMenu(const int trow)
 
 void LogWindow::slotDoubleClickLog(const QModelIndex & index)
 {
-    //qDebug() << "LogWindow::slotDoubleClickLog: Row: " << QString::number(index.row()) << "Column: " << QString::number(index.column()) << endl;
+     //qDebug() << "LogWindow::slotDoubleClickLog: Row: " << QString::number(index.row()) << "Column: " << QString::number(index.column()) << endl;
 
     int row = index.row();
     //qsoToEdit((logModel->index(row, 0)).data(0).toInt());
     int qsoID = ((logModel->index(row, Qt::DisplayRole)).data(0)).toInt();
 
-    //qDebug() << "LogWindow::slotDoubleClickLog: n: " << QString::number (logModel->data(index, Qt::DisplayRole).toInt()) << endl;
-    //qDebug() << "LogWindow::slotDoubleClickLog: emitted: " << QString::number (((logModel->index(row, Qt::DisplayRole)).data(0)).toInt()) << endl;
+     //qDebug() << "LogWindow::slotDoubleClickLog: n: " << QString::number (logModel->data(index, Qt::DisplayRole).toInt()) << endl;
+     //qDebug() << "LogWindow::slotDoubleClickLog: emitted: " << QString::number (((logModel->index(row, Qt::DisplayRole)).data(0)).toInt()) << endl;
 
     emit actionQSODoubleClicked(qsoID);
     //qsoToEdit((logModel->index(row, 0)).data(0).toInt());
@@ -261,20 +259,20 @@ void LogWindow::slotDoubleClickLog(const QModelIndex & index)
 
 bool LogWindow::isQSLReceived(const int _qsoId)
 {
-    //qDebug() << "LogWindow::isQSLReceived: " << QString::number(_qsoId) << endl;
+     //qDebug() << "LogWindow::isQSLReceived: " << QString::number(_qsoId) << endl;
     return dataProxy->isQSLReceived(_qsoId);
 }
 
 bool LogWindow::isQSLSent(const int _qsoId)
 {
-    //qDebug() << "LogWindow::isQSLSent: " << QString::number(_qsoId) << endl;
+     //qDebug() << "LogWindow::isQSLSent: " << QString::number(_qsoId) << endl;
 
     return dataProxy->isQSLSent(_qsoId);
 }
 
 void LogWindow::showMenuRightButtonFromLogCreateActions()
 {
-//qDebug() << "LogWindow::showMenuRightButtonFromLogCreateActions" << endl;
+ //qDebug() << "LogWindow::showMenuRightButtonFromLogCreateActions" << endl;
 
 
   delQSOFromLogAct = new QAction(tr("&Delete"), this);
@@ -313,7 +311,7 @@ void LogWindow::showMenuRightButtonFromLogCreateActions()
 
 void LogWindow::slotQSLSentViaBureauFromLog()
 {
-   //qDebug() << "LogWindow::slotQSLSentViaBureauFromLog: " << (qslSentViaBureauFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslSentViaBureauFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) ) << endl;
+    //qDebug() << "LogWindow::slotQSLSentViaBureauFromLog: " << (qslSentViaBureauFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslSentViaBureauFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) ) << endl;
     int _qsoId = ((logModel->index( ( (qslSentViaBureauFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
     qslSentViaBureau(_qsoId);
 
@@ -321,7 +319,7 @@ void LogWindow::slotQSLSentViaBureauFromLog()
 
 void LogWindow::slotQSLSentViaDirectFromLog()
 {
-    //qDebug() << "LogWindow::slotQSLSentViaDirectFromLog: " << (qslSentViaDirectFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslSentViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) ) << endl;
+     //qDebug() << "LogWindow::slotQSLSentViaDirectFromLog: " << (qslSentViaDirectFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslSentViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) ) << endl;
     int _qsoId = ((logModel->index( ( (qslSentViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
     dataProxy->qslSentViaDirect(_qsoId, (QDateTime::currentDateTime()).toString("yyyy/MM/dd"));
 
@@ -329,7 +327,7 @@ void LogWindow::slotQSLSentViaDirectFromLog()
 
 void LogWindow::slotQSLRecViaBureauFromLog()
 {
-   //qDebug() << "LogWindow::slotQSLRecViaBureauFromLog: " << (qslRecViaBureauAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslRecViaBureauAct->data()).toInt()  ) , 0)).data(0).toInt()) ) << endl;
+    //qDebug() << "LogWindow::slotQSLRecViaBureauFromLog: " << endl;
 
     int _qsoId = ((logModel->index( ( (qslRecViaBureauFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
     qslRecViaBureau(_qsoId);
@@ -338,7 +336,7 @@ void LogWindow::slotQSLRecViaBureauFromLog()
 
 void LogWindow::slotQSLRecViaDirectFromLog()
 {
-    //qDebug() << "LogWindow::slotQSLRecViaDirectFromLog: " << (qslRecViaDirectFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) ) << endl;
+     //qDebug() << "LogWindow::slotQSLRecViaDirectFromLog: " << (qslRecViaDirectFromLogAct->data()).toString() << " - Id = " << QString::number( ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt()) ) << endl;
     int _qsoId = ((logModel->index( ( (qslRecViaDirectFromLogAct->data()).toInt()  ) , 0)).data(0).toInt());
     qslRecViaDirect(_qsoId);
     // Mark Sent, Bureau, date, update log.
@@ -347,7 +345,7 @@ void LogWindow::slotQSLRecViaDirectFromLog()
 
 void LogWindow::slotQSOToEditFromLog()
 {
-    //qDebug() << "slotQSOToEditFromLog: " << (qsoToEditFromLogAct->data()).toString() << endl;
+     //qDebug() << "slotQSOToEditFromLog: " << (qsoToEditFromLogAct->data()).toString() << endl;
 
     //qsoToEdit((logModel->index((qsoToEditFromLogAct->data()).toInt(), 0)).data(0).toInt());
     int QSOid = ((logModel->index((qsoToEditFromLogAct->data()).toInt(), 0)).data(0)).toInt();
@@ -365,14 +363,14 @@ void LogWindow::slotQSOToEditFromLog()
 
 void LogWindow::deleteQSO(const int _qsoID)
 {
-    //qDebug() << "LogWindow::deleteQSO: " << QString::number(_qsoID) << endl;
+     //qDebug() << "LogWindow::deleteQSO: " << QString::number(_qsoID) << endl;
     elogClublog->deleteQSO(dataProxy->getClubLogRealTimeFromId(_qsoID));
     dataProxy->deleteQSO(_qsoID);
 
     //logModel->removeRow((delQSOFromLogAct->data()).toInt()); //TODO: This has been replaced by the previous line
     awards->recalculateAwards();
     refresh();       
-    dxccStatusWidget->refresh();
+    //dxccStatusWidget->refresh();
     emit updateAwards();
     emit updateSearchText();
 
@@ -380,7 +378,7 @@ void LogWindow::deleteQSO(const int _qsoID)
 
 void LogWindow::slotQsoDeleteFromLog()
 {
-   //qDebug() << "LogWindow::slotQsoDeleteFromLog: " << (delQSOFromLogAct->data()).toString() << endl;
+    //qDebug() << "LogWindow::slotQsoDeleteFromLog: " << (delQSOFromLogAct->data()).toString() << endl;
     //TODO: To be added to the logWindow and create an action that emist the QSO id
 
     QMessageBox msgBox;
@@ -393,11 +391,11 @@ void LogWindow::slotQsoDeleteFromLog()
 
     int QSOid = ((logModel->index((delQSOFromLogAct->data()).toInt(), 0)).data(0)).toInt();
 
-   //qDebug() << "LogWindow::slotQsoDeleteFromLog (id): " << QString::number(QSOid) << endl;
+    //qDebug() << "LogWindow::slotQsoDeleteFromLog (id): " << QString::number(QSOid) << endl;
 
     switch (ret) {
       case QMessageBox::Yes:
-       //qDebug() << "LogWindow::slotQsoDeleteFromLog (id): -1" << endl;
+        //qDebug() << "LogWindow::slotQsoDeleteFromLog (id): -1" << endl;
         deleteQSO(QSOid);
 
           break;
@@ -412,14 +410,14 @@ void LogWindow::slotQsoDeleteFromLog()
 
 void LogWindow::qslSentViaBureau(const int _qsoId)
 {
-    //qDebug() << "LogWindow::qslSentViaBureau: " << QString::number(_qsoId) << endl;
+     //qDebug() << "LogWindow::qslSentViaBureau: " << QString::number(_qsoId) << endl;
 
     dataProxy->qslSentViaBureau(_qsoId, (QDateTime::currentDateTime()).toString("yyyy/MM/dd"));
 }
 
 void LogWindow::qslRecViaBureau(const int _qsoId)
 {
-   // //qDebug() << "LogWindow::qslRecViaBureau: " << QString::number(_qsoId) << "/" << (dateTime->currentDateTime()).toString("yyyy/MM/dd") << endl;
+   //  //qDebug() << "LogWindow::qslRecViaBureau: " << QString::number(_qsoId) << "/" << (dateTime->currentDateTime()).toString("yyyy/MM/dd") << endl;
     dataProxy->qslRecViaBureau(_qsoId, (QDateTime::currentDateTime()).toString("yyyy/MM/dd"), false);
     awards->setAwards(_qsoId);   //Update the Award status
 
@@ -430,7 +428,7 @@ void LogWindow::qslRecViaBureau(const int _qsoId)
 
 void LogWindow::qslRecViaDirect(const int _qsoId)
 {
-    //qDebug() << "LogWindow::qslRecViaDirect: " << QString::number(_qsoId) << endl;
+     //qDebug() << "LogWindow::qslRecViaDirect: " << QString::number(_qsoId) << endl;
 
     dataProxy->qslRecViaDirect(_qsoId, (QDateTime::currentDateTime()).toString("yyyy/MM/dd"), false);
     awards->setAwards(_qsoId);
