@@ -64,6 +64,9 @@
 #include "infowidget.h"
 #include "showerrordialog.h"
 #include "udpserver.h"
+#include "statisticswidget.h"
+#include "updatesatsdata.h"
+
 
 
 
@@ -129,6 +132,7 @@ public:
 
 private slots:
     //void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString failedQuery);
+    void slotClearNoMorErrorShown();
     void slotQueryErrorManagement(QString functionFailed, QString errorCodeS, int errorCodeN, QString queryFailed);
     void slotQRZReturnPressed();
     void slotQRZSpacePressed();
@@ -142,6 +146,7 @@ private slots:
     void slotFreqRXChanged();
 
     void slotSearchBoxTextChanged();
+    void slotCloseStats(bool _vis);
     void slotSearchToolNeededQSLToSend();
     void slotToolSearchRequestedQSLToSend();
     void slotToolSearchNeededQSLPendingToReceive();
@@ -202,6 +207,7 @@ private slots:
     void slotRQSLExport();
     void slotCabrilloExport();
     //void slotQSLViaTextChanged();
+    void slotTimeOutInfoBars(); // Clears the infoLabels when the timeout emits the signal
 
 
 //TODO: REMOVE EQSL
@@ -215,6 +221,8 @@ private slots:
     void slotSetPropMode(const QString _p);
     void slotFillEmptyDXCCInTheLog();
     void slotUpdateCTYDAT();
+    void slotUpdateSATSDAT();
+    void slotShowStats();
     void slotWorldReload();
 
     void slotExitFromSlotDialog(const int exitID);
@@ -277,10 +285,21 @@ private slots:
     void slotShowQSOFromDXCCWidget(const int _q);
     void slotShowQSOsFromDXCCWidget(QList<int> _qsos);
 
+    //UDP Server (WXJT-x)
+    void slotWSJXstatusFromUDPServer(const int _type, const QString _dxcall, const double _freq, const QString _mode,
+                                 const QString _report, const QString _de_call, const QString _de_grid,
+                                 const QString _dx_grid, const QString _sub_mode);
+
+
+
+    void slotWSJTXloggedQSO(const int _type, const QString _dxcall, const double _freq, const QString _mode,
+                             const QString _dx_grid, const QString _time_off, const QString _report_sent, const QString _report_rec,
+                             const QString _tx_power, const QString _comments, const QString _name, const QString _time_on, const QString _de_call, const QString _de_grid);
+
 private:
     bool maybeSave();
 
-
+    UpdateSatsData *updateSatsData;
     //UPDATE CTY.DAT
     DownLoadCTY *downloadcty;
     //</UPDATE CTY.DAT>
@@ -311,6 +330,7 @@ private:
     QString readDataFromUI(); // Reads the QSO data from the UI and returns the SQL Query
     QString readDataFromUIDX();
     QString readDataFromUIDXModifying();
+    void actionsJustAfterAddingOneQSO();
     void clearForNextQSO();
     void clearUIDX(bool full=false); //full= false leaves some data to allow pileup or normal Dx in same band; full removes freqs and everything
 
@@ -334,7 +354,8 @@ private:
     void selectDefaultMode();
     void readActiveBands (const QStringList actives);
     void readActiveModes (const QStringList actives);
-
+    bool checkIfNewMode(const QString _mode);
+    void addNewValidMode(const QString _mode);
 
     void qsoToEdit (const int _qso);
 
@@ -369,7 +390,7 @@ private:
     QPushButton *addButton;
     //QLabel *distShortLabelN;
     //QLabel *distLongLabelN;
-
+    StatisticsWidget *statsWidget;
     DXCCStatusWidget *dxccStatusWidget;
     //QSqlRelationalTableModel *logModel;
     //QWidget *logPanel;
@@ -446,6 +467,8 @@ private:
     QAction *lotwMarkSentYesAct;
 
     QAction *downloadCTYAct;
+    QAction *downloadSATSAct;
+    QAction *showStatsAct;
 
     QAction *loggWinAct;
 /*
@@ -521,6 +544,8 @@ private:
 
     bool qslingNeeded;
     bool noMoreErrorShown;              // If true, the errors shown in slotQueryErrorManagement will not be shown anymore in that KLog execution
+    bool noMoreModeErrorShown;          // If true, the non-valid modes received from WSJT-x will not be showed to the user
+    bool wsjtxAutoLog;                  // If true, logged QSO are automatically logged into the log when sent from WSJTX
     MainWindowSatTab *satTabWidget;
     MainWindowMyDataTab *myDataTabWidget;
     MainWindowInputComment *commentTabWidget;
@@ -546,8 +571,10 @@ private:
     // </CLUSTER>
 
     // </UI>
-    QTimer *timer;
+    int infoTimeout; // timeout that temporary info will stay in the infobars
+    QTimer *timer, *timerInfoBars;
     QDateTime *dateTime;
+    QString infoLabel1T, infoLabel2T;
 
     QString klogDir, ctyDatFile, defaultADIFLogFile, configFileName;
     QString softwareVersion;
