@@ -34,54 +34,56 @@ This class calls all the othet "Setup..." to manage the configuration
 
 SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
 {
-    //qDebug() << "SetupDialog::SetupDialog 1" << endl;
+     //qDebug() << "SetupDialog::SetupDialog 1" << endl;
     util = new Utilities;
     constrid = 1;
     nolog = true;
     configFileName = "klogrc";
     version = ".";
     pageRequested = 0;
-  //qDebug() << "SetupDialog::SetupDialog 2" << endl;
+   //qDebug() << "SetupDialog::SetupDialog 2" << endl;
     dataProxy = dp;
-   //qDebug() << "SetupDialog::SetupDialog 3" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3" << endl;
 
     firstTime = _firstTime;
     if (firstTime)
     {
-       //qDebug() << "SetupDialog::SetupDialog FIRST TIME = TRUE" << endl;
+        //qDebug() << "SetupDialog::SetupDialog FIRST TIME = TRUE" << endl;
     }
     else
     {
-       //qDebug() << "SetupDialog::SetupDialog FIRST TIME = FALSE" << endl;
+        //qDebug() << "SetupDialog::SetupDialog FIRST TIME = FALSE" << endl;
     }
-   //qDebug() << "SetupDialog::SetupDialog 3.1" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3.1" << endl;
 
     logsPageTabN=-1;
-   //qDebug() << "SetupDialog::SetupDialog 3.2" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3.2" << endl;
     locator = new Locator();
-   //qDebug() << "SetupDialog::SetupDialog 3.3" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3.3" << endl;
     tabWidget = new QTabWidget;
-   //qDebug() << "SetupDialog::SetupDialog 3.4" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3.4" << endl;
 
 
     userDataPage = new SetupPageUserDataPage(dataProxy);
-   //qDebug() << "SetupDialog::SetupDialog 3.5" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3.5" << endl;
     bandModePage = new SetupPageBandMode(dataProxy, this);
-   //qDebug() << "SetupDialog::SetupDialog 3.6" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3.6" << endl;
     dxClusterPage = new SetupPageDxCluster(this);
-   //qDebug() << "SetupDialog::SetupDialog 3.7" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3.7" << endl;
     colorsPage = new SetupPageColors(this);
-   //qDebug() << "SetupDialog::SetupDialog 3.8" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3.8" << endl;
     miscPage = new SetupPageMisc(this);
-   //qDebug() << "SetupDialog::SetupDialog 3.9" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3.9" << endl;
     worldEditorPage = new SetupPageWorldEditor (dataProxy, this);
-   //qDebug() << "SetupDialog::SetupDialog 3.10" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3.10" << endl;
     logsPage = new SetupPageLogs(dataProxy, this);
-   //qDebug() << "SetupDialog::SetupDialog 3.11" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 3.11" << endl;
     clubLogPage = new SetupPageClubLog(this);
-   //qDebug() << "SetupDialog::SetupDialog 3.12" << endl;
+     //qDebug() << "SetupDialog::SetupDialog 3.12" << endl;
+    UDPPage = new SetupPageUDP(this);
+    //qDebug() << "SetupDialog::SetupDialog 3.13" << endl;
 
-   //qDebug() << "SetupDialog::SetupDialog 4" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 4" << endl;
 
     tabWidget->addTab(userDataPage, tr("My Data"));    
     tabWidget->addTab(bandModePage, tr("Bands/Modes"));
@@ -90,7 +92,9 @@ SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
     tabWidget->addTab(miscPage, tr("Misc"));
     tabWidget->addTab(worldEditorPage, tr("World Editor"));
     logsPageTabN = tabWidget->addTab(logsPage, tr("Logs"));
-    tabWidget->addTab(clubLogPage, tr("ClubLog"));
+    tabWidget->addTab(clubLogPage, "ClubLog");
+    tabWidget->addTab(UDPPage, "WSJT-X");
+
 
     QPushButton *closeButton = new QPushButton(tr("Cancel"));
     QPushButton *okButton = new QPushButton(tr("OK"));
@@ -125,13 +129,13 @@ SetupDialog::SetupDialog(DataProxy *dp, const bool _firstTime)
         tabWidget->setCurrentIndex(logsPageTabN);
     }
     nolog = !(haveAtleastOneLog());
-  //qDebug() << "SetupDialog::SetupDialog 1 END" << endl;
+   //qDebug() << "SetupDialog::SetupDialog 1 END" << endl;
 }
 
 
 SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
 {
-    //qDebug() << "SetupDialog::SetupDialog 2" << endl;
+     //qDebug() << "SetupDialog::SetupDialog 2" << endl;
     constrid = 2;
     util = new Utilities;
     firstTime = _firstTime;
@@ -140,7 +144,7 @@ SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString
     version = _softwareVersion;
     pageRequested = _page;
     int logsPageTabN=-1;
-    //qDebug() << "SetupDialog::SetupDialog 01" << endl;
+     //qDebug() << "SetupDialog::SetupDialog 01" << endl;
 
     locator = new Locator();
 
@@ -154,7 +158,9 @@ SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString
     worldEditorPage = new SetupPageWorldEditor (dataProxy, this);
     logsPage = new SetupPageLogs(dataProxy, this);
     clubLogPage = new SetupPageClubLog(this);
-    //qDebug() << "SetupDialog::SetupDialog 02" << endl;
+    UDPPage = new SetupPageUDP(this);
+
+     //qDebug() << "SetupDialog::SetupDialog 02" << endl;
     tabWidget->addTab(userDataPage, tr("User data"));
     tabWidget->addTab(bandModePage, tr("Bands/Modes"));
     tabWidget->addTab(dxClusterPage, tr("D&X-Cluster"));
@@ -163,14 +169,13 @@ SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString
     tabWidget->addTab(worldEditorPage, tr("World Editor"));
     logsPageTabN = tabWidget->addTab(logsPage, tr("Logs"));
     tabWidget->addTab(clubLogPage, tr("ClubLog"));
+    tabWidget->addTab(UDPPage, tr("WSJT-X"));
 
-    //qDebug() << "SetupDialog::SetupDialog 03" << endl;
+     //qDebug() << "SetupDialog::SetupDialog 03" << endl;
 
     QPushButton *closeButton = new QPushButton(tr("Cancel"));
     QPushButton *okButton = new QPushButton(tr("OK"));
 
-
-
     QHBoxLayout *horizontalLayout = new QHBoxLayout;
     horizontalLayout->addWidget(tabWidget);
 
@@ -183,36 +188,36 @@ SetupDialog::SetupDialog(DataProxy *dp, const QString _configFile, const QString
     mainLayout->addLayout(horizontalLayout);
     mainLayout->addLayout(buttonsLayout);
 
-    //qDebug() << "SetupDialog::SetupDialog 04" << endl;
+     //qDebug() << "SetupDialog::SetupDialog 04" << endl;
 
     setLayout(mainLayout);
 
     setWindowTitle(tr("Config Dialog"));
 
-    //qDebug() << "SetupDialog::SetupDialog 05" << endl;
+     //qDebug() << "SetupDialog::SetupDialog 05" << endl;
 
     slotReadConfigData();
-    //qDebug() << "SetupDialog::SetupDialog 05.1" << endl;
+     //qDebug() << "SetupDialog::SetupDialog 05.1" << endl;
 
     if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
     {
-       //qDebug() << "SetupDialog::SetupDialog 05.2" << endl;
+        //qDebug() << "SetupDialog::SetupDialog 05.2" << endl;
         tabWidget->setCurrentIndex(logsPageTabN);
     }
-   //qDebug() << "SetupDialog::SetupDialog 05.3" << endl;
+    //qDebug() << "SetupDialog::SetupDialog 05.3" << endl;
     nolog = !(haveAtleastOneLog());
 
     connect(closeButton, SIGNAL(clicked()), this, SLOT(slotCancelButtonClicked()));
     connect(okButton, SIGNAL(clicked()), this, SLOT(slotOkButtonClicked()));
     connectActions();
 
-    //qDebug() << "SetupDialog::SetupDialog 2  - END" << endl;
+     //qDebug() << "SetupDialog::SetupDialog 2  - END" << endl;
 }
 
 
 SetupDialog::~SetupDialog()
 {
-    //qDebug() << "SetupDialog::~SetupDialog " << endl;
+     //qDebug() << "SetupDialog::~SetupDialog " << endl;
 }
 
 void SetupDialog::connectActions()
@@ -227,16 +232,16 @@ void SetupDialog::connectActions()
 
 void SetupDialog::setData(const QString _configFile, const QString _softwareVersion, const int _page, const bool _firstTime)
 {
-  //qDebug() << "SetupDialog::setData: " << QString::number(_page) << endl;
+   //qDebug() << "SetupDialog::setData: " << QString::number(_page) << endl;
     nolog = !(haveAtleastOneLog());
     firstTime = _firstTime;
     if (firstTime)
     {
-       //qDebug() << "SetupDialog::setData FIRST TIME! " << endl;
+        //qDebug() << "SetupDialog::setData FIRST TIME! " << endl;
     }
     else
     {
-       //qDebug() << "SetupDialog::setData NOT FIRST TIME! " << endl;
+        //qDebug() << "SetupDialog::setData NOT FIRST TIME! " << endl;
 
         miscPage->setUseDefaultDBPath(miscPage->getDefaultDBPath());
     }
@@ -250,20 +255,20 @@ void SetupDialog::setData(const QString _configFile, const QString _softwareVers
 
 void SetupDialog::setConfigFile(const QString _configFile)
 {
-    //qDebug() << "SetupDialog::setConfigFile" << endl;
+     //qDebug() << "SetupDialog::setConfigFile" << endl;
     configFileName = _configFile;
 }
 
 void SetupDialog::setSoftVersion(const QString _softwareVersion)
 {
-    //qDebug() << "SetupDialog::setSoftVersion" << endl;
+     //qDebug() << "SetupDialog::setSoftVersion" << endl;
     version = _softwareVersion;
 }
 
 
 void SetupDialog::setPage(const int _page)
 {
-    //qDebug() << "SetupDialog::setPage("<<QString::number(_page) << ")" << endl;
+     //qDebug() << "SetupDialog::setPage("<<QString::number(_page) << ")" << endl;
     pageRequested = _page;
 
     if ((pageRequested==6) && (logsPageTabN>0))// The user is opening a new log
@@ -275,7 +280,7 @@ void SetupDialog::setPage(const int _page)
 void SetupDialog::slotCancelButtonClicked()
 {
 
-    //qDebug() << "SetupDialog::slotCancelButtonClicked" << endl;
+     //qDebug() << "SetupDialog::slotCancelButtonClicked" << endl;
     if (firstTime || nolog)
     {
         if (nolog)
@@ -295,7 +300,7 @@ void SetupDialog::slotCancelButtonClicked()
 
 void SetupDialog::createIcons()
 {
-    //qDebug() << "SetupDialog::createIcons" << endl;
+     //qDebug() << "SetupDialog::createIcons" << endl;
     QListWidgetItem *configButton = new QListWidgetItem(contentsWidget);
     configButton->setIcon(QIcon(":/images/config.png"));
     configButton->setText(tr("User data"));
@@ -346,7 +351,7 @@ void SetupDialog::createIcons()
 
 void SetupDialog::changePage(QListWidgetItem *current, QListWidgetItem *previous)
 {
-    //qDebug() << "SetupDialog::changePage" << endl;
+     //qDebug() << "SetupDialog::changePage" << endl;
     if (!current)
         current = previous;
 
@@ -364,7 +369,7 @@ qDebug() << "SetupDialog::slotOkButtonClicked" << endl;
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Warning);
         msgBox.setText(tr("DB has not been moved to new path"));
-        msgBox.setInformativeText(tr("Go to the") + " " + tr("Misc tab") + " " + tr("and click on") + " " + tr("Move DB") + "\n" + tr("or the DB will not be moved to the new location."));
+        msgBox.setInformativeText(tr("Go to the Misc tab and click on Move DB\n or the DB will not be moved to the new location."));
         msgBox.exec();
         return;
     }
@@ -373,14 +378,14 @@ qDebug() << "SetupDialog::slotOkButtonClicked" << endl;
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Information);
         msgBox.setText(tr("You need to enter at least a valid QRZ."));
-        msgBox.setInformativeText(tr("Go to the") + " " + tr("User tab") + " " + tr("and enter valid QRZ."));
+        msgBox.setInformativeText(tr("Go to the User tab and enter valid QRZ."));
         msgBox.exec();
         return;
     }
 
     if (!haveAtleastOneLog())
     {
-       //qDebug() << "SetupDialog::slotOkButtonClicked - NO LOG!" << endl;
+        //qDebug() << "SetupDialog::slotOkButtonClicked - NO LOG!" << endl;
 
         QMessageBox msgBox;
         msgBox.setIcon(QMessageBox::Information);
@@ -507,8 +512,6 @@ qDebug() << "SetupDialog::slotOkButtonClicked" << endl;
         stream << "ShowCallsignInSearch=" << miscPage->getShowStationCallSignInSearch() << ";" <<  endl;
         stream << "KeepMyData=" << miscPage->getKeepMyData() << ";" <<  endl;
         stream << "CompleteWithPrevious=" << miscPage->getCompleteWithPrevious() << ";" <<  endl;
-	stream << "UDPServer=" << miscPage->getUDPServer() << ";" <<  endl;
-        stream << "UDPServerPort=" << miscPage->getUDPServerPort() << ";" <<  endl;
         stream << "CheckNewVersions=" << miscPage->getCheckNewVersions() << ";" <<  endl;
 
         if ((miscPage->getReportInfo()).toUpper() == "TRUE")
@@ -564,17 +567,27 @@ qDebug() << "SetupDialog::slotOkButtonClicked" << endl;
 
         // CLUBLOG
 
+        //WSJTX
+        stream << "UDPServer=" << UDPPage->getUDPServer() << ";" <<  endl;
+        stream << "UDPServerPort=" << UDPPage->getUDPServerPort() << ";" <<  endl;
+        stream << "LogFromWSJTX=" << UDPPage->getLogFromWSJTx() << ";" <<  endl;
+        stream << "LogAutoFromWSJTX=" << UDPPage->getAutoLogFromWSJTx() << ";" <<  endl;
+        stream << "RealTimeFromWSJTX=" << UDPPage->getReaDataFromWSJTx() << ";" <<  endl;
+        stream << "InfoTimeOut=" << UDPPage->getTimeout() << ";" <<  endl;
+
+        //WSJTX
+
         file.close ();
     }
-    //qDebug() << "SetupDialog::slotOkButtonClicked - just before leaving" << endl;
+     //qDebug() << "SetupDialog::slotOkButtonClicked - just before leaving" << endl;
     QDialog::accept();
-    //qDebug() << "SetupDialog::slotOkButtonClicked - END" << endl;
+     //qDebug() << "SetupDialog::slotOkButtonClicked - END" << endl;
     //close();
 }
 
 void SetupDialog::slotReadConfigData()
 {
-    //qDebug() << "SetupDialog::slotReadConfigData" << endl;
+     //qDebug() << "SetupDialog::slotReadConfigData" << endl;
     if (firstTime)
     {
         setDefaults();
@@ -584,15 +597,15 @@ void SetupDialog::slotReadConfigData()
         bandModePage->setActiveBands(bands);
     }
 
-        //qDebug() << "SetupDialog::slotReadConfigData - 1" << endl;
+         //qDebug() << "SetupDialog::slotReadConfigData - 1" << endl;
 
     QFile file(configFileName);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
-        //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << endl;
+         //qDebug() << "SetupDialog::slotReadConfigData() File not found" << configFileName << endl;
         //firstTime = true;
         return;
     }
-    //qDebug() << "SetupDialog::slotReadConfigData - 2" << endl;
+     //qDebug() << "SetupDialog::slotReadConfigData - 2" << endl;
     //dxClusterServers.clear();
 
 
@@ -600,9 +613,9 @@ void SetupDialog::slotReadConfigData()
     while (!file.atEnd()) {
         QByteArray line = file.readLine();
         processConfigLine(line);        
-       //qDebug() << "SetupDialog::slotReadConfigData - in the while" << endl;
+        //qDebug() << "SetupDialog::slotReadConfigData - in the while" << endl;
     }
-    //qDebug() << "SetupDialog::slotReadConfigData - 3" << endl;
+     //qDebug() << "SetupDialog::slotReadConfigData - 3" << endl;
 
     dxClusterPage->setDxclusterServersComboBox(dxClusterServers);
     dxClusterPage->setSelectedDxClusterServer(dxClusterServerToUse);
@@ -618,19 +631,19 @@ void SetupDialog::slotReadConfigData()
 
     }
     modes.removeDuplicates();
-    //qDebug() << "SetupDialog::slotReadConfigData - duplicate modes: " << QString::number(a)  << endl;
+     //qDebug() << "SetupDialog::slotReadConfigData - duplicate modes: " << QString::number(a)  << endl;
     bandModePage->setActiveModes(modes);
     bands.removeDuplicates();
-  //qDebug() << "SetupDialog::slotReadConfigData - duplicate bands: " << QString::number(a)  << endl;
+   //qDebug() << "SetupDialog::slotReadConfigData - duplicate bands: " << QString::number(a)  << endl;
     bandModePage->setActiveBands(bands);
-   //qDebug() << "SetupDialog::slotReadConfigData - END" << endl;
+    //qDebug() << "SetupDialog::slotReadConfigData - END" << endl;
 
 }
 
 bool SetupDialog::processConfigLine(const QString _line)
 {
 
-   //qDebug() << "SetupDialog::processConfigLine: " << _line << endl;
+    //qDebug() << "SetupDialog::processConfigLine: " << _line << endl;
 
     QString line = _line.simplified();
     //line.simplified();
@@ -640,11 +653,11 @@ bool SetupDialog::processConfigLine(const QString _line)
 
 
     if (line.startsWith('#')){
-        //qDebug() << "SetupDialog::processConfigLine: Comment Line!" << endl;
+         //qDebug() << "SetupDialog::processConfigLine: Comment Line!" << endl;
         return true;
     }
     if (!( (line.contains('=')) && (line.contains(';')))){
-        //qDebug() << "SetupDialog::processConfigLine: Wrong Line!" << endl;
+         //qDebug() << "SetupDialog::processConfigLine: Wrong Line!" << endl;
         return false;
     }
     QString value = values.at(1);
@@ -658,7 +671,7 @@ bool SetupDialog::processConfigLine(const QString _line)
     value = checkAndFixASCIIinADIF(value); // Check whether the value is valid.
 
     if (tab == "CALLSIGN"){
-        //qDebug() << "SetupDialog::processConfigLine: CALLSIGN: " << value << endl;
+         //qDebug() << "SetupDialog::processConfigLine: CALLSIGN: " << value << endl;
         userDataPage->setStationQrz(value);
     }else if (tab == "OPERATORS"){
         userDataPage->setOperators(value);
@@ -691,7 +704,7 @@ bool SetupDialog::processConfigLine(const QString _line)
         miscPage->setUseDefaultDBPath(value);
     }else if (tab=="DEFAULTADIFFILE"){
         miscPage->setDefaultFileName(value.toLower());
-        //qDebug() << "SetupDialog::processConfigLine: FILE: " << value << endl;
+         //qDebug() << "SetupDialog::processConfigLine: FILE: " << value << endl;
     }else if (tab=="IMPERIALSYSTEM"){
         miscPage->setImperial(value.toLower());
     }else if (tab=="KEEPMYDATA"){
@@ -711,10 +724,26 @@ bool SetupDialog::processConfigLine(const QString _line)
         miscPage->setReportInfo(value);
     }
     else if (tab=="UDPSERVER"){
-        miscPage->setUDPServer(value);
+        UDPPage->setUDPServer(value);
     }
     else if (tab=="UDPSERVERPORT"){
-        miscPage->setUDPServerPort(value);
+        UDPPage->setUDPServerPort(value);
+    }
+    else if (tab=="LOGFROMWSJTX")
+    {
+        UDPPage->setLogFromWSJTx(value);
+    }
+    else if (tab=="LOGAUTOFROMWSJTX")
+    {
+        UDPPage->setAutoLogFromWSJTx(value);
+    }
+    else if (tab=="REALTIMEFROMWSJTX")
+    {
+        UDPPage->setReaDataFromWSJTx(value);
+    }
+    else if (tab=="INFOTIMEOUT")
+    {
+        UDPPage->setTimeout(value);
     }
     else if (tab =="NAME")
     {
@@ -806,7 +835,7 @@ bool SetupDialog::processConfigLine(const QString _line)
         dxClusterPage->setShowWCYRadiobutton(value);
     }else if(tab =="DXCLUSTERSERVERPORT"){
         dxClusterServers << value;
-        //qDebug() << "SetupDialog::processConfigLine: dxClusterServers: " << dxClusterServers.last() << endl;
+         //qDebug() << "SetupDialog::processConfigLine: dxClusterServers: " << dxClusterServers.last() << endl;
 
     }else if (tab  =="DXCLUSTERSERVERTOUSE"){
         dxClusterServerToUse=value;
@@ -822,16 +851,16 @@ bool SetupDialog::processConfigLine(const QString _line)
     }else if(tab =="DEFAULTCOLOR"){
         colorsPage->setDefaultColor(value);
     }else if(tab =="SELECTEDLOG"){
-        //qDebug() << "SetupDialog::processConfigLine: SELECTEDLOG: " << value << endl;
+         //qDebug() << "SetupDialog::processConfigLine: SELECTEDLOG: " << value << endl;
         i = value.toInt();
 
         if (dataProxy->doesThisLogExist(i))
         {
-            //qDebug() << "SetupDialog::processConfigLine: dataProxy->doesThisLogExist TRUE" << endl;
+             //qDebug() << "SetupDialog::processConfigLine: dataProxy->doesThisLogExist TRUE" << endl;
         }
         else
         {
-            //qDebug() << "SetupDialog::processConfigLine: dataProxy->doesThisLogExist FALSE" << endl;
+             //qDebug() << "SetupDialog::processConfigLine: dataProxy->doesThisLogExist FALSE" << endl;
             i = 0;
             while(!dataProxy->doesThisLogExist(i))
             {
@@ -839,7 +868,7 @@ bool SetupDialog::processConfigLine(const QString _line)
             }
         }
         logsPage->setSelectedLog(i);
-        //qDebug() << "SetupDialog::processConfigLine: dataProxy->doesThisLogExist END" << endl;
+         //qDebug() << "SetupDialog::processConfigLine: dataProxy->doesThisLogExist END" << endl;
 
     }else if(tab =="CLUBLOGACTIVE"){
         clubLogPage->setClubLog(value);
@@ -859,12 +888,12 @@ bool SetupDialog::processConfigLine(const QString _line)
     else if(tab =="CLUBLOGUSESTATIONCALLSIGN"){
             clubLogPage->setUseStationCall(value);
     }else{
-        //qDebug() << "SetupDialog::processConfigLine: NONE: " << endl;
+         //qDebug() << "SetupDialog::processConfigLine: NONE: " << endl;
     }
 
     // Lines are: Option = value;
 
-    //qDebug() << "SetupDialog::processConfigLine: END "  << endl;
+     //qDebug() << "SetupDialog::processConfigLine: END "  << endl;
     return true;
 
 
@@ -873,7 +902,7 @@ bool SetupDialog::processConfigLine(const QString _line)
 void SetupDialog::readActiveBands (const QString actives)
 { // Checks a "10m, 12m" QString, checks if  they are valid bands and import to the
     // bands used in the program
-   //qDebug() << "SetupDialog::readActiveBands: " << actives << endl;
+    //qDebug() << "SetupDialog::readActiveBands: " << actives << endl;
 
     bool atLeastOne = false;
 
@@ -886,13 +915,13 @@ void SetupDialog::readActiveBands (const QString actives)
         {
             if (!atLeastOne)
             {
-                //qDebug() << "SetupDialog::readActiveBands (at least One!): " << values.at(i) << endl;
+                 //qDebug() << "SetupDialog::readActiveBands (at least One!): " << values.at(i) << endl;
                 atLeastOne = true;
                 _abands.clear();
             }
 
             _abands << values.at(i);
-            //qDebug() << "SetupDialog::readActiveBands: " << values.at(i) << endl;
+             //qDebug() << "SetupDialog::readActiveBands: " << values.at(i) << endl;
         }
 
     }
@@ -908,7 +937,7 @@ void SetupDialog::readActiveBands (const QString actives)
 
 void SetupDialog::readActiveModes (const QString actives)
 {
-    //qDebug() << "SetupDialog::readActiveModes: " << actives << endl;
+     //qDebug() << "SetupDialog::readActiveModes: " << actives << endl;
 
     bool atLeastOne = false;
     QStringList _amodes;//, _backModes;
@@ -934,12 +963,12 @@ void SetupDialog::readActiveModes (const QString actives)
     modes << dataProxy->getModesInLog(-1);
     modes << _amodes;
     modes.removeDuplicates();
-    //qDebug() << "SetupDialog::readActiveModes: " << modes.join(" / ") << endl;
+     //qDebug() << "SetupDialog::readActiveModes: " << modes.join(" / ") << endl;
 }
 
 bool SetupDialog::isValidBand (const QString b)
 {
-    //qDebug() << "SetupDialog::isValidBand: "<< b << endl;
+     //qDebug() << "SetupDialog::isValidBand: "<< b << endl;
     QString stringQuery = QString("SELECT id FROM band WHERE name='%1'").arg(b);
     QSqlQuery query(stringQuery);
     query.next();
@@ -948,7 +977,7 @@ bool SetupDialog::isValidBand (const QString b)
 }
 bool SetupDialog::isValidMode (const QString b)
 {
-    //qDebug() << "SetupDialog::isValidMode: " << b << endl;
+     //qDebug() << "SetupDialog::isValidMode: " << b << endl;
 
     QString stringQuery = QString("SELECT id FROM mode WHERE name='%1'").arg(b);
     QSqlQuery query(stringQuery);
@@ -959,7 +988,7 @@ bool SetupDialog::isValidMode (const QString b)
 
 void SetupDialog::setDefaults()
 {
-    //qDebug() << "SetupDialog::setDefaults" << endl;
+     //qDebug() << "SetupDialog::setDefaults" << endl;
     //miscPage->setInMemory("TRUE");
     miscPage->setRealTime("TRUE");
     miscPage->setUTCTime("TRUE");
@@ -970,8 +999,13 @@ void SetupDialog::setDefaults()
     miscPage->setKeepMyData("TRUE");
     miscPage->setCheckNewVersions("TRUE");
     miscPage->setReportInfo("FALSE");
-    miscPage->setUDPServer("TRUE");
-    miscPage->setUDPServerPort("2237");
+
+    UDPPage->setUDPServer("FALSE");
+    UDPPage->setUDPServerPort("2237");
+    UDPPage->setTimeout("2000");
+    UDPPage->setLogFromWSJTx("FALSE");
+    UDPPage->setReaDataFromWSJTx("FALSE");
+    UDPPage->setAutoLogFromWSJTx("FALSE");
 
     dxClusterPage->setShowHFRadiobutton("TRUE");
     dxClusterPage->setShowVHFRadiobutton("TRUE");
@@ -1001,7 +1035,7 @@ void SetupDialog::setDefaults()
 
 QString SetupDialog::checkAndFixASCIIinADIF(const QString _data)
 {
-    //qDebug() << "SetupDialog::checkAndFixASCIIinADIF " << _data << endl;
+     //qDebug() << "SetupDialog::checkAndFixASCIIinADIF " << _data << endl;
 //TODO: this function is also in the FileManager class. Maybe I should call that one and keep just one copy
     ushort unicodeVal;
     QString st = _data;
@@ -1015,7 +1049,7 @@ QString SetupDialog::checkAndFixASCIIinADIF(const QString _data)
         {
             newString.append(st.at(i));
         }
-        //qDebug() << "SetupDialog::checkAndFixunicodeinADIF: " << st.at(i) <<" = " << QString::number(unicodeVal) << endl;
+         //qDebug() << "SetupDialog::checkAndFixunicodeinADIF: " << st.at(i) <<" = " << QString::number(unicodeVal) << endl;
     }
 
     // Show into another lineEdit
@@ -1044,34 +1078,34 @@ void SetupDialog::setClubLogActive(const bool _b)
 
 void SetupDialog::checkIfNewBandOrMode()
 {
-   //qDebug() << "SetupDialog::checkIfNewBandOrMode " << endl;
+    //qDebug() << "SetupDialog::checkIfNewBandOrMode " << endl;
     QStringList _items;
 
     _items.clear();
-    //qDebug() << "SetupDialog::checkIfNewBandOrMode -1" << endl;
+     //qDebug() << "SetupDialog::checkIfNewBandOrMode -1" << endl;
     _items << dataProxy->getBandsInLog(-1);
-    //qDebug() << "SetupDialog::checkIfNewBandOrMode -2" << endl;
+     //qDebug() << "SetupDialog::checkIfNewBandOrMode -2" << endl;
     _items << (bandModePage->getBands()).split(", ", QString::SkipEmptyParts);
-    //qDebug() << "SetupDialog::checkIfNewBandOrMode -3" << endl;
+     //qDebug() << "SetupDialog::checkIfNewBandOrMode -3" << endl;
     _items.removeDuplicates();
-    //qDebug() << "SetupDialog::checkIfNewBandOrMode -4" << endl;
+     //qDebug() << "SetupDialog::checkIfNewBandOrMode -4" << endl;
     bandModePage->setActiveBands(_items);
-    //qDebug() << "SetupDialog::checkIfNewBandOrMode -5" << endl;
+     //qDebug() << "SetupDialog::checkIfNewBandOrMode -5" << endl;
 
     _items.clear();
     _items << dataProxy->getModesInLog(-1);
     _items << (bandModePage->getModes()).split(", ", QString::SkipEmptyParts);
     _items.removeDuplicates();
     bandModePage->setActiveModes(_items);
-    //qDebug() << "SetupDialog::checkIfNewBandOrMode END" << endl;
+     //qDebug() << "SetupDialog::checkIfNewBandOrMode END" << endl;
 
 }
 
 
 void SetupDialog::slotAnalyzeNewLogData(const QStringList _qs)
 {
-   //qDebug() << "SetupDialog::slotAnalyzeNewLogData (length=" << QString::number(_qs.length()) << ")" << endl;
-    //qDebug() << "SetupDialog::slotAnalyzeNewLogData" << endl;
+    //qDebug() << "SetupDialog::slotAnalyzeNewLogData (length=" << QString::number(_qs.length()) << ")" << endl;
+     //qDebug() << "SetupDialog::slotAnalyzeNewLogData" << endl;
  // We receive the station callsign and operators from the logs tab
     if (_qs.length()!=2)
     {
@@ -1084,13 +1118,13 @@ void SetupDialog::slotAnalyzeNewLogData(const QStringList _qs)
 
 void SetupDialog::slotSetStationCallSign(const QString _p)
 {
-    //qDebug() << "SetupDialog::slotSetStationCallSign: " << _p << endl;
+     //qDebug() << "SetupDialog::slotSetStationCallSign: " << _p << endl;
     logsPage->setDefaultStationCallsign(_p);
 }
 
 void SetupDialog::slotSetOperators(const QString _p)
 {
-    //qDebug() << "SetupDialog::slotSetOperators: " << _p << endl;
+     //qDebug() << "SetupDialog::slotSetOperators: " << _p << endl;
     logsPage->setDefaultOperators(_p);
 }
 
