@@ -31,7 +31,7 @@
 //      instead. It is easy to change but the code would not be so clear... Think about this. :-)
 
 SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
-    //qDebug() << "SetupPageMisc::SetupPageMisc" << endl;
+     //qDebug() << "SetupPageMisc::SetupPageMisc" << endl;
 
     util = new Utilities;
 
@@ -53,8 +53,6 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     fileNameButton = new QPushButton (tr("Browse"));
     dbPushButton = new QPushButton (tr("Browse"));
     moveDBPushButton = new QPushButton(tr("Move DB"));
-    UDPServerCheckBox = new QCheckBox(tr("Start UDP Server"), this);
-    UDPServerPortSpinBox = new QSpinBox;
 
     dbPathApplied = true;
 
@@ -69,11 +67,11 @@ SetupPageMisc::SetupPageMisc(QWidget *parent) : QWidget(parent){
     {
         moveDBPushButton->setEnabled(true);
     }
-    //qDebug() << "SetupPageMisc::SetupPageMisc - END" << endl;
+     //qDebug() << "SetupPageMisc::SetupPageMisc - END" << endl;
 }
 
 SetupPageMisc::~SetupPageMisc(){
-    //qDebug() << "SetupPageMisc::~SetupPageMisc" << endl;
+     //qDebug() << "SetupPageMisc::~SetupPageMisc" << endl;
 }
 
 void SetupPageMisc::createUI()
@@ -84,11 +82,11 @@ void SetupPageMisc::createUI()
 
     //TODO: To be removed when the defaultDir is saved in the config file
     #ifdef Q_OS_WIN
-    //qDebug() << "WINDOWS DETECTED!"  << endl;
+     //qDebug() << "WINDOWS DETECTED!"  << endl;
     klogDir = util->getHomeDir();  // We create the \klog for the logs and data
     defaultFileName = klogDir+"/klog.adi";
     #else
-    //qDebug() << "NO WINDOWS DETECTED!"  << endl;
+     //qDebug() << "NO WINDOWS DETECTED!"  << endl;
     klogDir = util->getHomeDir();  // We create the ~/.klog for the logs and data
     defaultFileName = klogDir+"/klog.adi";
     #endif
@@ -105,8 +103,8 @@ void SetupPageMisc::createUI()
     
     //UDPServerCheckBox->setChecked(true);
     //UDPServerPortSpinBox->setEnabled(true);
-    UDPServerCheckBox->setEnabled(false);
-    UDPServerPortSpinBox->setEnabled(false);
+    //UDPServerCheckBox->setEnabled(false);
+    //UDPServerPortSpinBox->setEnabled(false);
 
     useDefaultName->setChecked(true);
     alwaysADIFCheckBox->setChecked(true);
@@ -119,7 +117,7 @@ void SetupPageMisc::createUI()
     keepMyDataCheckBox->setToolTip(tr("All the data from the My Data tab will be used or data from the previous QSO will be maintained."));
     checkNewVersionCheckBox->setToolTip(tr("Check if there is a new release of KLog available every time you start KLog."));
     provideCallCheckBox->setToolTip(tr("If new version checking is selected, KLog will send the developer your callsign, KLog version & Operating system to help in improving KLog."));
-    imperialCheckBox ->setToolTip(tr("Check it for Imperial system (Miles instead of Kilometres)."));
+    imperialCheckBox ->setToolTip(tr("Check it for Imperial system (Miles instead of Kilometers)."));
     realTimeCheckbox->setToolTip(tr("Select to use real time."));
     UTCCheckbox->setToolTip(tr("Select to use UTC time."));
     alwaysADIFCheckBox->setToolTip(tr("Select if you want to save to ADIF on exit."));    
@@ -130,20 +128,7 @@ void SetupPageMisc::createUI()
     fileNameButton->setToolTip(tr("Click to change the default ADIF file."));
     dbPushButton->setToolTip(tr("Click to change the path of the database."));
     moveDBPushButton->setToolTip(tr("Click to move the DB to the new directory."));
-    UDPServerCheckBox->setToolTip(tr("UDP Server will receive QSOs sent from other programs like WSJT-X allowing you to log in KLog automatically from those programs."));
-    UDPServerPortSpinBox->setToolTip(tr("UDP port number where the UDP Server will listen for connections. Make sure it is the same port where the other programs are sending the data to."));
 
-    UDPServerPortSpinBox->setMinimum(0);
-    UDPServerPortSpinBox->setMaximum(65535);
-    QLabel *udpPortLabel = new QLabel(tr("UDP Port"));
-    udpPortLabel->setBuddy(UDPServerPortSpinBox);
-    udpPortLabel->setAlignment(Qt::AlignVCenter| Qt::AlignCenter);
-    udpPortLabel->setEnabled(false);
-
-    QHBoxLayout *UDPLayout = new QHBoxLayout;
-    UDPLayout->addWidget(UDPServerCheckBox);
-    UDPLayout->addWidget(udpPortLabel);
-    UDPLayout->addWidget(UDPServerPortSpinBox);
 
     QHBoxLayout *fileLayout = new QHBoxLayout;
     fileLayout->addWidget(useDefaultName);
@@ -166,7 +151,7 @@ void SetupPageMisc::createUI()
     mainLayou1->addLayout(fileLayout, 0, 0, 1, -1);
     mainLayou1->addLayout(dbLayout, 1, 0, 1, -1);
     mainLayou1->addWidget(alwaysADIFCheckBox, 2, 0, 1, 1);
-    mainLayou1->addLayout(UDPLayout, 2, 1, 1, 1);
+    //mainLayou1->addLayout(UDPLayout, 2, 1, 1, 1);
     mainLayou1->addWidget(UTCCheckbox, 3, 0, 1, 1);
     mainLayou1->addWidget(realTimeCheckbox, 3, 1, 1, 1);
     mainLayou1->addWidget(imperialCheckBox, 4, 0, 1, 1);
@@ -192,7 +177,7 @@ void SetupPageMisc::createActions(){
     connect(dbPushButton, SIGNAL(clicked () ), this, SLOT(slotDBButtonClicked() ) );
     connect(dbPathLineEdit, SIGNAL(textChanged(QString)), this, SLOT(slotDBLineEditChanged() ) );
     connect(moveDBPushButton, SIGNAL(clicked () ), this, SLOT(slotMoveDBButtonClicked() ) );
-    connect(UDPServerCheckBox, SIGNAL(clicked () ), this, SLOT(slotUDPServerCheckBoxClicked() ) );
+    //connect(UDPServerCheckBox, SIGNAL(clicked () ), this, SLOT(slotUDPServerCheckBoxClicked() ) );
 
 }
 
@@ -277,7 +262,7 @@ QString SetupPageMisc::getDefaultFileName()
 }
 void SetupPageMisc::setDefaultFileName(const QString t)
 {
-    //qDebug() << "SetupPageMisc::setDefaultFileName: " << t << endl;
+     //qDebug() << "SetupPageMisc::setDefaultFileName: " << t << endl;
     defaultFileName = t;
     defaultFileNameLineEdit->setText(defaultFileName);
 }
@@ -379,7 +364,7 @@ void SetupPageMisc::setImperial(const QString t)
 
 void SetupPageMisc::slotUseDefaultButtonStateChanged(int state)
 {
-    //qDebug() << "SetupPageMisc::slotUseDefaultButtonStateChanged" << endl;
+     //qDebug() << "SetupPageMisc::slotUseDefaultButtonStateChanged" << endl;
 
     if (state)
     {
@@ -499,63 +484,7 @@ void SetupPageMisc::setCompleteWithPrevious(const QString t)
     }
 }
 
-void SetupPageMisc::slotUDPServerCheckBoxClicked()
-{
-    if ( UDPServerCheckBox->isChecked())
-    {
-        //UDPServerPortSpinBox->setEnabled(true);
-    }
-    else
-    {
-        //UDPServerPortSpinBox->setEnabled(false);
-    }
-}
 
-QString SetupPageMisc::getUDPServer()
-{
-    if (UDPServerCheckBox->isChecked())
-    {
-        return "True";
-    }
-    else
-    {
-        return "False";
-    }
-}
-
-void SetupPageMisc::setUDPServer(const QString t)
-{
-    if ( (t.toUpper()) == "FALSE")
-    {
-        UDPServerCheckBox->setChecked(false);
-    }
-    else
-    {
-        UDPServerCheckBox->setChecked(true);
-    }
-}
-
-void SetupPageMisc::setUDPServerPort(const QString t)
-{
-    if (  (t.toInt()>=0) && (t.toInt()<=65535))
-    {
-        UDPServerPortSpinBox->setValue(t.toInt());
-    }
-}
-
-QString SetupPageMisc::getUDPServerPort()
-{
-    int t = UDPServerPortSpinBox->value();
-
-    if (  (t>=0) && (t<=65535) )
-    {
-        return QString::number(t);
-    }
-    else
-    {
-        return "-1";
-    }
-}
 
 void SetupPageMisc::slotcheckNewVersionCheckBoxClicked()
 {
@@ -666,7 +595,7 @@ void SetupPageMisc::slotDBButtonClicked()
 
 void SetupPageMisc::slotDBLineEditChanged()
 {
-    //qDebug() << "SetupPageMisc::slotDBLineEditChanged: " << dbPathLineEdit->text() << endl;
+     //qDebug() << "SetupPageMisc::slotDBLineEditChanged: " << dbPathLineEdit->text() << endl;
     QString aux;
     aux = dbPathLineEdit->text();
 
@@ -700,8 +629,8 @@ void SetupPageMisc::slotMoveDBButtonClicked()
     QString target = dbDirNew + "/logbook.dat";
     QMessageBox msgBox;
 
-    //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (source): " << source << endl;
-    //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (target): " << target << endl;
+     //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (source): " << source << endl;
+     //qDebug() << "SetupPageMisc::slotMoveDBButtonClicked (target): " << target << endl;
     if ( QFile::exists(dbDirNew) )
     {
         //dbDirCurrent
