@@ -27,7 +27,7 @@
 #include "setuppageuserdata.h"
 
 SetupPageUserDataPage::SetupPageUserDataPage(DataProxy *dp, QWidget *parent) : QWidget(parent){
-   //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage" << endl;
+    //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage" << endl;
    locator = new Locator();
    dataProxy = dp;
    world = new World(dataProxy);
@@ -67,15 +67,15 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy *dp, QWidget *parent) : Q
    provinceLineEdit = new QLineEdit;
    countryLineEdit = new QLineEdit;
 
-   nameLineEdit->setToolTip(tr("Enter your name"));
-   address1LineEdit->setToolTip(tr("Enter your address - 1st line"));
-   address2LineEdit->setToolTip(tr("Enter your address - 2nd line"));
-   address3LineEdit->setToolTip(tr("Enter your address - 3rd line"));
-   address4LineEdit->setToolTip(tr("Enter your address - 4th line"));
-   cityLineEdit->setToolTip(tr("Enter your city"));
-   zipLineEdit->setToolTip(tr("Enter your zip code"));
-   provinceLineEdit->setToolTip(tr("Enter your province or state"));
-   countryLineEdit->setToolTip(tr("Enter your country"));
+   nameLineEdit->setToolTip(tr("Enter your name."));
+   address1LineEdit->setToolTip(tr("Enter your address - 1st line."));
+   address2LineEdit->setToolTip(tr("Enter your address - 2nd line."));
+   address3LineEdit->setToolTip(tr("Enter your address - 3rd line."));
+   address4LineEdit->setToolTip(tr("Enter your address - 4th line."));
+   cityLineEdit->setToolTip(tr("Enter your city."));
+   zipLineEdit->setToolTip(tr("Enter your zip code."));
+   provinceLineEdit->setToolTip(tr("Enter your province or state."));
+   countryLineEdit->setToolTip(tr("Enter your country."));
 
    QLabel *nameLabel = new QLabel(tr("&Name"));
    QLabel *addressLabel = new QLabel(tr("&Address"));
@@ -136,13 +136,13 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy *dp, QWidget *parent) : Q
    myPowerSpinBox->setDecimals(2);
    myPowerSpinBox->setMaximum(9999);
 
-   rig1LineEdit->setToolTip(tr("Enter your information for rig") + " #1");
-   rig2LineEdit->setToolTip(tr("Enter your information for rig") + " #2");
-   rig3LineEdit->setToolTip(tr("Enter your information for rig") + " #3");
-   ant1LineEdit->setToolTip(tr("Enter your information for antenna") + " #1");
-   ant2LineEdit->setToolTip(tr("Enter your information for antenna") + " #2");
-   ant3LineEdit->setToolTip(tr("Enter your information for antenna") + " #3");
-   myPowerSpinBox->setToolTip(tr("Enter your power information"));
+   rig1LineEdit->setToolTip(tr("Enter your information for rig") + " #1.");
+   rig2LineEdit->setToolTip(tr("Enter your information for rig") + " #2.");
+   rig3LineEdit->setToolTip(tr("Enter your information for rig") + " #3.");
+   ant1LineEdit->setToolTip(tr("Enter your information for antenna") + " #1.");
+   ant2LineEdit->setToolTip(tr("Enter your information for antenna") + " #2.");
+   ant3LineEdit->setToolTip(tr("Enter your information for antenna") + " #3.");
+   myPowerSpinBox->setToolTip(tr("Enter your power information."));
 
    QLabel *rig1Label = new QLabel(tr("&Rig 1"));
    QLabel *rig2Label = new QLabel(tr("R&ig 2"));
@@ -183,7 +183,7 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy *dp, QWidget *parent) : Q
     stationTab->setLayout(stationLayout);
 
     //TODO:Defining ALL the tooltips
-    qrzLineEdit->setToolTip(tr("Enter the station callsign that will be used for logging"));
+    qrzLineEdit->setToolTip(tr("Enter the station callsign that will be used for logging."));
     operatorsLineEdit->setToolTip(tr("Enter the operators (comma separated if more than one)."));
     myLocatorLineEdit->setToolTip(tr("Enter the locator of your station. Alternatively, KLog can use an approximate locator based on your callsign."));
 
@@ -271,13 +271,13 @@ SetupPageUserDataPage::SetupPageUserDataPage(DataProxy *dp, QWidget *parent) : Q
 
     setLayout(mainLayout);
 
-    //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage - END" << endl;
+     //qDebug() << "SetupPageUserDataPage::SetupPageUserDataPage - END" << endl;
 }
 
 
 SetupPageUserDataPage::~SetupPageUserDataPage()
 {
-    //qDebug() << "SetupPageUserDataPage::~SetupPageUserDataPage" << endl;
+     //qDebug() << "SetupPageUserDataPage::~SetupPageUserDataPage" << endl;
 }
 
 QString SetupPageUserDataPage::getStationQrz()
@@ -302,7 +302,7 @@ void SetupPageUserDataPage::slotEnterKeyPressed()
 
 void SetupPageUserDataPage::slotQRZTextChanged()
 {
-   //qDebug() << "SetupPageUserDataPage::slotQRZTextChanged: " << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << endl;
+    //qDebug() << "SetupPageUserDataPage::slotQRZTextChanged: " << qrzLineEdit->text() << " / Length: " << QString::number((qrzLineEdit->text()).size()) << endl;
     int i = qrzLineEdit->cursorPosition();
     QString _a = qrzLineEdit->text();
     if ((_a.at(i-1)).isSpace())
@@ -356,7 +356,7 @@ bool SetupPageUserDataPage::setITUz(const int _ituz){
 
 void SetupPageUserDataPage::slotMyLocatorTextChanged()
 {
-    //qDebug() << "SetupPageUserDataPage::slotMyLocatorTextChanged: " << myLocatorLineEdit->text() << endl;
+     //qDebug() << "SetupPageUserDataPage::slotMyLocatorTextChanged: " << myLocatorLineEdit->text() << endl;
 
     //int i;
     myLocatorLineEdit->setText(((myLocatorLineEdit->text())).simplified());
@@ -620,7 +620,7 @@ bool SetupPageUserDataPage::setAntenna3 (const QString _aux)
 
 void SetupPageUserDataPage::slotOperatorsChanged()
 {
-    //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged" << endl;
+     //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged" << endl;
     //QString _operators = operatorsLineEdit->text();
     if (operatorsLineEdit->text().length() < 1)
         return;
@@ -629,7 +629,7 @@ void SetupPageUserDataPage::slotOperatorsChanged()
 
     //int ent = -1;
 
-    //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-00" << endl;
+     //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-00" << endl;
     QString _a = operatorsLineEdit->text();
 
     if ((_a.at(i-1)).isSpace())
@@ -637,7 +637,7 @@ void SetupPageUserDataPage::slotOperatorsChanged()
         operatorsLineEdit->setText(_a.remove(i-1, 1));
     }
 
-    //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-01" << endl;
+     //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-01" << endl;
 
     //operatorsLineEdit->setText(((operatorsLineEdit->text())).simplified());
     //operatorsLineEdit->setText((operatorsLineEdit->text()).toUpper());
@@ -646,12 +646,12 @@ void SetupPageUserDataPage::slotOperatorsChanged()
 
     QStringList operators = _a.split(",", QString::SkipEmptyParts);
 
-    //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-02" << endl;
-    //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-02.5 Size: " << QString::number(operators.size()) << endl;
+     //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-02" << endl;
+     //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-02.5 Size: " << QString::number(operators.size()) << endl;
 
     for (int ii = 0; ii < operators.size(); ++ii)
     {
-        //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-03 - " << QString::number(ii) << endl;
+         //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-03 - " << QString::number(ii) << endl;
 
         operatorsOK = world->checkQRZValidFormat(operators.at(ii));
 
@@ -659,20 +659,20 @@ void SetupPageUserDataPage::slotOperatorsChanged()
 
         if (operatorsOK)
         {
-            //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: NO  VALID CALL: " <<  operators.at(ii) << endl;
+             //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: NO  VALID CALL: " <<  operators.at(ii) << endl;
         }
         else
         {
-            //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: VALID CALL: " <<  operators.at(ii) << endl;
+             //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: VALID CALL: " <<  operators.at(ii) << endl;
         }
     }
     //          cout << fonts.at(i).toLocal8Bit().constData() << endl;
 
-    //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-04" << endl;
+     //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-04" << endl;
 
     if (operatorsOK)
     {
-        //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: VALID FORMAT" << endl;
+         //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: VALID FORMAT" << endl;
         //QColor defaultColor = (operatorsLineEdit->palette()).color(QPalette::WindowText);
 
         operatorsLineEdit->setPalette(*defaultPalette);
@@ -683,9 +683,9 @@ void SetupPageUserDataPage::slotOperatorsChanged()
     else
     {
          operatorsLineEdit->setPalette(*wrongPalette);
-        //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: NOT VALID FORMAT" << endl;
+         //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged: NOT VALID FORMAT" << endl;
     }
-    //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-05" << endl;
+     //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-05" << endl;
 
  /*
     cqzLineEdit->setText(QString::number(world->getQRZCqz(qrzLineEdit->text())));
@@ -696,7 +696,7 @@ void SetupPageUserDataPage::slotOperatorsChanged()
   */
     //operatorsLineEdit->setText(_a);
     operatorsLineEdit->setCursorPosition(i);
-    //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-END" << endl;
+     //qDebug() << "SetupPageUserDataPage::slotOperatorsChanged-END" << endl;
 }
 
 QString SetupPageUserDataPage::getOperators()
